@@ -21,8 +21,8 @@ from cinder.api import extensions
 from cinder.api.openstack import wsgi
 from cinder.api.views import transfers as transfer_view
 from cinder.api import xmlutil
-
 from cinder import exception
+from cinder.i18n import _
 from cinder.openstack.common import log as logging
 from cinder import transfer as transferAPI
 from cinder import utils
@@ -128,8 +128,9 @@ class VolumeTransferController(wsgi.Controller):
     def _get_transfers(self, req, is_detail):
         """Returns a list of transfers, transformed through view builder."""
         context = req.environ['cinder.context']
-        LOG.debug(_('Listing volume transfers'))
-        transfers = self.transfer_api.get_all(context)
+        filters = req.params.copy()
+        LOG.debug('Listing volume transfers')
+        transfers = self.transfer_api.get_all(context, filters=filters)
         limited_list = common.limited(transfers, req)
 
         if is_detail:
@@ -144,7 +145,7 @@ class VolumeTransferController(wsgi.Controller):
     @wsgi.deserializers(xml=CreateDeserializer)
     def create(self, req, body):
         """Create a new volume transfer."""
-        LOG.debug(_('Creating new volume transfer %s'), body)
+        LOG.debug('Creating new volume transfer %s', body)
         if not self.is_valid_body(body, 'transfer'):
             raise exc.HTTPBadRequest()
 
@@ -159,9 +160,9 @@ class VolumeTransferController(wsgi.Controller):
 
         name = transfer.get('name', None)
 
-        LOG.audit(_("Creating transfer of volume %s"),
-                  volume_id,
-                  context=context)
+        LOG.info(_("Creating transfer of volume %s"),
+                 volume_id,
+                 context=context)
 
         try:
             new_transfer = self.transfer_api.create(context, volume_id, name)
@@ -180,7 +181,7 @@ class VolumeTransferController(wsgi.Controller):
     def accept(self, req, id, body):
         """Accept a new volume transfer."""
         transfer_id = id
-        LOG.debug(_('Accepting volume transfer %s'), transfer_id)
+        LOG.debug('Accepting volume transfer %s', transfer_id)
         if not self.is_valid_body(body, 'accept'):
             raise exc.HTTPBadRequest()
 
@@ -193,8 +194,8 @@ class VolumeTransferController(wsgi.Controller):
             msg = _("Incorrect request body format")
             raise exc.HTTPBadRequest(explanation=msg)
 
-        LOG.audit(_("Accepting transfer %s"), transfer_id,
-                  context=context)
+        LOG.info(_("Accepting transfer %s"), transfer_id,
+                 context=context)
 
         try:
             accepted_transfer = self.transfer_api.accept(context, transfer_id,
@@ -214,7 +215,7 @@ class VolumeTransferController(wsgi.Controller):
         """Delete a transfer."""
         context = req.environ['cinder.context']
 
-        LOG.audit(_("Delete transfer with id: %s"), id, context=context)
+        LOG.info(_("Delete transfer with id: %s"), id, context=context)
 
         try:
             self.transfer_api.delete(context, transfer_id=id)
