@@ -23,7 +23,7 @@ from cinder.brick.initiator import host_driver
 from cinder.brick.initiator import linuxfc
 from cinder.brick.initiator import linuxscsi
 from cinder.brick.remotefs import remotefs
-from cinder.openstack.common.gettextutils import _
+from cinder.i18n import _
 from cinder.openstack.common import lockutils
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import loopingcall
@@ -199,11 +199,11 @@ class ISCSIConnector(InitiatorConnector):
             #multipath installed, discovering other targets if available
             target_portal = connection_properties['target_portal']
             out = self._run_iscsiadm_bare(['-m',
-                                          'discovery',
-                                          '-t',
-                                          'sendtargets',
-                                          '-p',
-                                          target_portal],
+                                           'discovery',
+                                           '-t',
+                                           'sendtargets',
+                                           '-p',
+                                           target_portal],
                                           check_exit_code=[0, 255])[0] \
                 or ""
 
@@ -239,8 +239,8 @@ class ISCSIConnector(InitiatorConnector):
                 time.sleep(tries ** 2)
 
         if tries != 0:
-            LOG.debug(_("Found iSCSI node %(host_device)s "
-                        "(after %(tries)s rescans)"),
+            LOG.debug("Found iSCSI node %(host_device)s "
+                      "(after %(tries)s rescans)",
                       {'host_device': host_device, 'tries': tries})
 
         if self.use_multipath:
@@ -291,7 +291,8 @@ class ISCSIConnector(InitiatorConnector):
                          {'portal': connection_properties['target_portal'],
                           'iqn': connection_properties['target_iqn']})
         devices = self.driver.get_all_block_devices()
-        devices = [dev for dev in devices if dev.startswith(device_prefix)]
+        devices = [dev for dev in devices if dev.startswith(device_prefix)
+                   and os.path.exists(dev)]
 
         if not devices:
             self._disconnect_from_iscsi_portal(connection_properties)
@@ -350,21 +351,22 @@ class ISCSIConnector(InitiatorConnector):
         block_devices = self.driver.get_all_block_devices()
         devices = []
         for dev in block_devices:
-            if "/mapper/" in dev:
-                devices.append(dev)
-            else:
-                mpdev = self._get_multipath_device_name(dev)
-                if mpdev:
-                    devices.append(mpdev)
+            if os.path.exists(dev):
+                if "/mapper/" in dev:
+                    devices.append(dev)
+                else:
+                    mpdev = self._get_multipath_device_name(dev)
+                    if mpdev:
+                        devices.append(mpdev)
 
         # Do a discovery to find all targets.
         # Targets for multiple paths for the same multipath device
         # may not be the same.
         out = self._run_iscsiadm_bare(['-m',
-                                      'discovery',
-                                      '-t',
-                                      'sendtargets',
-                                      '-p',
+                                       'discovery',
+                                       '-t',
+                                       'sendtargets',
+                                       '-p',
                                       connection_properties['target_portal']],
                                       check_exit_code=[0, 255])[0] \
             or ""
@@ -599,9 +601,10 @@ class FibreChannelConnector(InitiatorConnector):
                 for wwn in wwns:
                     target_wwn = "0x%s" % wwn.lower()
                     host_device = ("/dev/disk/by-path/pci-%s-fc-%s-lun-%s" %
-                                  (pci_num,
-                                   target_wwn,
-                                   connection_properties.get('target_lun', 0)))
+                                   (pci_num,
+                                    target_wwn,
+                                    connection_properties.get(
+                                        'target_lun', 0)))
                     host_devices.append(host_device)
 
         if len(host_devices) == 0:
@@ -616,7 +619,7 @@ class FibreChannelConnector(InitiatorConnector):
         def _wait_for_device_discovery(host_devices):
             tries = self.tries
             for device in host_devices:
-                LOG.debug(_("Looking for Fibre Channel dev %(device)s"),
+                LOG.debug("Looking for Fibre Channel dev %(device)s",
                           {'device': device})
                 if os.path.exists(device):
                     self.host_device = device
@@ -646,8 +649,8 @@ class FibreChannelConnector(InitiatorConnector):
 
         tries = self.tries
         if self.host_device is not None and self.device_name is not None:
-            LOG.debug(_("Found Fibre Channel volume %(name)s "
-                        "(after %(tries)s rescans)"),
+            LOG.debug("Found Fibre Channel volume %(name)s "
+                      "(after %(tries)s rescans)",
                       {'name': self.device_name, 'tries': tries})
 
         # see if the new drive is part of a multipath
@@ -655,7 +658,7 @@ class FibreChannelConnector(InitiatorConnector):
         if self.use_multipath:
             mdev_info = self._linuxscsi.find_multipath_device(self.device_name)
             if mdev_info is not None:
-                LOG.debug(_("Multipath device discovered %(device)s")
+                LOG.debug("Multipath device discovered %(device)s"
                           % {'device': mdev_info['device']})
                 device_path = mdev_info['device']
                 devices = mdev_info['devices']
@@ -787,8 +790,8 @@ class AoEConnector(InitiatorConnector):
         timer.start(interval=2).wait()
 
         if waiting_status['tries']:
-            LOG.debug(_("Found AoE device %(path)s "
-                        "(after %(tries)s rediscover)"),
+            LOG.debug("Found AoE device %(path)s "
+                      "(after %(tries)s rediscover)",
                       {'path': aoe_path,
                        'tries': waiting_status['tries']})
 
@@ -813,7 +816,7 @@ class AoEConnector(InitiatorConnector):
                                    root_helper=self._root_helper,
                                    check_exit_code=0)
 
-        LOG.debug(_('aoe-discover: stdout=%(out)s stderr%(err)s') %
+        LOG.debug('aoe-discover: stdout=%(out)s stderr%(err)s' %
                   {'out': out, 'err': err})
 
     def _aoe_revalidate(self, aoe_device):
@@ -823,7 +826,7 @@ class AoEConnector(InitiatorConnector):
                                    root_helper=self._root_helper,
                                    check_exit_code=0)
 
-        LOG.debug(_('aoe-revalidate %(dev)s: stdout=%(out)s stderr%(err)s') %
+        LOG.debug('aoe-revalidate %(dev)s: stdout=%(out)s stderr%(err)s' %
                   {'dev': aoe_device, 'out': out, 'err': err})
 
     def _aoe_flush(self, aoe_device):
@@ -832,7 +835,7 @@ class AoEConnector(InitiatorConnector):
                                    run_as_root=True,
                                    root_helper=self._root_helper,
                                    check_exit_code=0)
-        LOG.debug(_('aoe-flush %(dev)s: stdout=%(out)s stderr%(err)s') %
+        LOG.debug('aoe-flush %(dev)s: stdout=%(out)s stderr%(err)s' %
                   {'dev': aoe_device, 'out': out, 'err': err})
 
 
