@@ -18,10 +18,11 @@
 import hashlib
 import os
 import re
+
 import six
 
 from cinder.brick import exception
-from cinder.openstack.common.gettextutils import _
+from cinder.i18n import _
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import processutils as putils
 
@@ -41,6 +42,12 @@ class RemoteFsClient(object):
                     err=_('nfs_mount_point_base required'))
             self._mount_options = kwargs.get('nfs_mount_options', None)
             self._check_nfs_options()
+        elif mount_type == "cifs":
+            self._mount_base = kwargs.get('smbfs_mount_point_base', None)
+            if not self._mount_base:
+                raise exception.InvalidParameterValue(
+                    err=_('smbfs_mount_point_base required'))
+            self._mount_options = kwargs.get('smbfs_mount_options', None)
         elif mount_type == "glusterfs":
             self._mount_base = kwargs.get('glusterfs_mount_point_base', None)
             if not self._mount_base:
@@ -120,13 +127,13 @@ class RemoteFsClient(object):
             options = self._nfs_mount_type_opts[mnt_type]
             try:
                 self._do_mount('nfs', nfs_share, mount_path, options, flags)
-                LOG.debug(_('Mounted %(sh)s using %(mnt_type)s.')
+                LOG.debug('Mounted %(sh)s using %(mnt_type)s.'
                           % {'sh': nfs_share, 'mnt_type': mnt_type})
                 return
             except Exception as e:
                 mnt_errors[mnt_type] = six.text_type(e)
-                LOG.debug(_('Failed to do %s mount.'), mnt_type)
-        raise exception.BrickException(_("NFS mount failed for share %(sh)s."
+                LOG.debug('Failed to do %s mount.', mnt_type)
+        raise exception.BrickException(_("NFS mount failed for share %(sh)s. "
                                          "Error - %(error)s")
                                        % {'sh': nfs_share,
                                           'error': mnt_errors})
