@@ -13,6 +13,7 @@
 from sqlalchemy import Boolean, Column, DateTime
 from sqlalchemy import Integer, MetaData, String, Table, ForeignKey
 
+from cinder.i18n import _
 from cinder.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
@@ -22,7 +23,7 @@ def upgrade(migrate_engine):
     meta = MetaData()
     meta.bind = migrate_engine
 
-    _volumes = Table('volumes', meta, autoload=True)
+    Table('volumes', meta, autoload=True)
 
     # New table
     volume_admin_metadata = Table(
