@@ -15,6 +15,10 @@
 from sqlalchemy import Column
 from sqlalchemy import MetaData, String, Table
 
+from cinder.openstack.common import log as logging
+
+LOG = logging.getLogger(__name__)
+
 
 def upgrade(migrate_engine):
     """Add replication columns to volumes."""
@@ -32,3 +36,16 @@ def upgrade(migrate_engine):
     volumes.update().values(replication_status='disabled',
                             replication_extended_status=None,
                             replication_driver_data=None).execute()
+
+
+def downgrade(migrate_engine):
+    meta = MetaData()
+    meta.bind = migrate_engine
+
+    volumes = Table('volumes', meta, autoload=True)
+    replication_status = volumes.columns.replication_status
+    replication_extended_status = volumes.columns.replication_extended_status
+    replication_driver_data = volumes.columns.replication_driver_data
+    volumes.drop_column(replication_status)
+    volumes.drop_column(replication_extended_status)
+    volumes.drop_column(replication_driver_data)
