@@ -164,7 +164,7 @@ def synchronized(name, lock_file_prefix, external=False, lock_path=None):
 
     :param external: The external keyword argument denotes whether this lock
     should work across multiple processes. This means that if two different
-    workers both run a a method decorated with @synchronized('mylock',
+    workers both run a method decorated with @synchronized('mylock',
     external=True), only one of them will execute at a time.
 
     :param lock_path: The lock_path keyword argument is used to specify a
