@@ -24,13 +24,18 @@ import random
 
 from oslo.config import cfg
 from oslo import messaging
+import osprofiler.notifier
+from osprofiler import profiler
+import osprofiler.web
 
 from cinder import context
 from cinder import db
 from cinder import exception
+from cinder.i18n import _
 from cinder.openstack.common import importutils
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import loopingcall
+from cinder.openstack.common import processutils
 from cinder.openstack.common import service
 from cinder import rpc
 from cinder import version
@@ -42,26 +47,55 @@ LOG = logging.getLogger(__name__)
 service_opts = [
     cfg.IntOpt('report_interval',
                default=10,
-               help='seconds between nodes reporting state to datastore'),
+               help='Interval, in seconds, between nodes reporting state '
+                    'to datastore'),
     cfg.IntOpt('periodic_interval',
                default=60,
-               help='seconds between running periodic tasks'),
+               help='Interval, in seconds, between running periodic tasks'),
     cfg.IntOpt('periodic_fuzzy_delay',
                default=60,
-               help='range of seconds to randomly delay when starting the'
+               help='Range, in seconds, to randomly delay when starting the'
                     ' periodic task scheduler to reduce stampeding.'
                     ' (Disable by setting to 0)'),
     cfg.StrOpt('osapi_volume_listen',
                default="0.0.0.0",
-               help='IP address for OpenStack Volume API to listen'),
+               help='IP address on which OpenStack Volume API listens'),
     cfg.IntOpt('osapi_volume_listen_port',
                default=8776,
-               help='port for os volume api to listen'),
+               help='Port on which OpenStack Volume API listens'),
     cfg.IntOpt('osapi_volume_workers',
-               help='Number of workers for OpenStack Volume API service'), ]
+               help='Number of workers for OpenStack Volume API service. '
+                    'The default is equal to the number of CPUs available.'), ]
+
+profiler_opts = [
+    cfg.BoolOpt("profiler_enabled", default=False,
+                help=_('If False fully disable profiling feature.')),
+    cfg.BoolOpt("trace_sqlalchemy", default=False,
+                help=_("If False doesn't trace SQL requests."))
+]
 
 CONF = cfg.CONF
 CONF.register_opts(service_opts)
+CONF.register_opts(profiler_opts, group="profiler")
+
+
+def setup_profiler(binary, host):
+    if CONF.profiler.profiler_enabled:
+        _notifier = osprofiler.notifier.create(
+            "Messaging", messaging, context.get_admin_context().to_dict(),
+            rpc.TRANSPORT, "cinder", binary, host)
+        osprofiler.notifier.set(_notifier)
+        LOG.warning("OSProfiler is enabled.\nIt means that person who knows "
+                    "any of hmac_keys that are specified in "
+                    "/etc/cinder/api-paste.ini can trace his requests. \n"
+                    "In real life only operator can read this file so there "
+                    "is no security issue. Note that even if person can "
+                    "trigger profiler, only admin user can retrieve trace "
+                    "information.\n"
+                    "To disable OSprofiler set in cinder.conf:\n"
+                    "[profiler]\nenabled=false")
+    else:
+        osprofiler.web.disable()
 
 
 class Service(service.Service):
@@ -85,6 +119,8 @@ class Service(service.Service):
         self.topic = topic
         self.manager_class_name = manager
         manager_class = importutils.import_class(self.manager_class_name)
+        manager_class = profiler.trace_cls("rpc")(manager_class)
+
         self.manager = manager_class(host=self.host,
                                      service_name=service_name,
                                      *args, **kwargs)
@@ -95,10 +131,12 @@ class Service(service.Service):
         self.saved_args, self.saved_kwargs = args, kwargs
         self.timers = []
 
+        setup_profiler(binary, host)
+
     def start(self):
         version_string = version.version_string()
-        LOG.audit(_('Starting %(topic)s node (version %(version_string)s)'),
-                  {'topic': self.topic, 'version_string': version_string})
+        LOG.info(_('Starting %(topic)s node (version %(version_string)s)'),
+                 {'topic': self.topic, 'version_string': version_string})
         self.model_disconnected = False
         self.manager.init_host()
         ctxt = context.get_admin_context()
@@ -110,7 +148,7 @@ class Service(service.Service):
         except exception.NotFound:
             self._create_service_ref(ctxt)
 
-        LOG.debug(_("Creating RPC server for service %s") % self.topic)
+        LOG.debug("Creating RPC server for service %s" % self.topic)
 
         target = messaging.Target(topic=self.topic, server=self.host)
         endpoints = [self.manager]
@@ -119,7 +157,8 @@ class Service(service.Service):
         self.rpcserver.start()
 
         if self.report_interval:
-            pulse = loopingcall.LoopingCall(self.report_state)
+            pulse = loopingcall.FixedIntervalLoopingCall(
+                self.report_state)
             pulse.start(interval=self.report_interval,
                         initial_delay=self.report_interval)
             self.timers.append(pulse)
@@ -130,7 +169,8 @@ class Service(service.Service):
             else:
                 initial_delay = None
 
-            periodic = loopingcall.LoopingCall(self.periodic_tasks)
+            periodic = loopingcall.FixedIntervalLoopingCall(
+                self.periodic_tasks)
             periodic.start(interval=self.periodic_interval,
                            initial_delay=initial_delay)
             self.timers.append(periodic)
@@ -247,8 +287,8 @@ class Service(service.Service):
             try:
                 service_ref = db.service_get(ctxt, self.service_id)
             except exception.NotFound:
-                LOG.debug(_('The service database object disappeared, '
-                            'Recreating it.'))
+                LOG.debug('The service database object disappeared, '
+                          'Recreating it.')
                 self._create_service_ref(ctxt)
                 service_ref = db.service_get(ctxt, self.service_id)
 
@@ -288,13 +328,17 @@ class WSGIService(object):
         self.app = self.loader.load_app(name)
         self.host = getattr(CONF, '%s_listen' % name, "0.0.0.0")
         self.port = getattr(CONF, '%s_listen_port' % name, 0)
-        self.workers = getattr(CONF, '%s_workers' % name, None)
-        if self.workers < 1:
-            LOG.warn(_("Value of config option %(name)s_workers must be "
-                       "integer greater than 1.  Input value ignored.") %
-                     {'name': name})
-            # Reset workers to default
-            self.workers = None
+        self.workers = (getattr(CONF, '%s_workers' % name, None) or
+                        processutils.get_worker_count())
+        if self.workers and self.workers < 1:
+            worker_name = '%s_workers' % name
+            msg = (_("%(worker_name)s value of %(workers)d is invalid, "
+                     "must be greater than 0.") %
+                   {'worker_name': worker_name,
+                    'workers': self.workers})
+            raise exception.InvalidInput(msg)
+        setup_profiler(name, self.host)
+
         self.server = wsgi.Server(name,
                                   self.app,
                                   host=self.host,
@@ -351,6 +395,14 @@ class WSGIService(object):
         """
         self.server.wait()
 
+    def reset(self):
+        """Reset server greenpool size to default.
+
+        :returns: None
+
+        """
+        self.server.reset()
+
 
 def process_launcher():
     return service.ProcessLauncher()
@@ -371,7 +423,7 @@ def serve(server, workers=None):
 
 
 def wait():
-    LOG.debug(_('Full set of CONF:'))
+    LOG.debug('Full set of CONF:')
     for flag in CONF:
         flag_get = CONF.get(flag, None)
         # hide flag contents from log if contains a password
@@ -379,7 +431,7 @@ def wait():
         if ("_password" in flag or "_key" in flag or
                 (flag == "sql_connection" and
                     ("mysql:" in flag_get or "postgresql:" in flag_get))):
-            LOG.debug(_('%s : FLAG SET ') % flag)
+            LOG.debug('%s : FLAG SET ' % flag)
         else:
             LOG.debug('%(flag)s : %(flag_get)s' %
                       {'flag': flag, 'flag_get': flag_get})
