@@ -18,9 +18,9 @@ Tests for Backup code.
 """
 
 import json
-import mock
 from xml.dom import minidom
 
+import mock
 import webob
 
 # needed for stubs to work
@@ -28,6 +28,7 @@ import cinder.backup
 from cinder import context
 from cinder import db
 from cinder import exception
+from cinder.i18n import _
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import timeutils
 from cinder import test
@@ -57,13 +58,13 @@ class BackupsAPITestCase(test.TestCase):
                        display_description='this is a test backup',
                        container='volumebackups',
                        status='creating',
-                       size=0, object_count=0):
+                       size=0, object_count=0, host='testhost'):
         """Create a backup object."""
         backup = {}
         backup['volume_id'] = volume_id
         backup['user_id'] = 'fake'
         backup['project_id'] = 'fake'
-        backup['host'] = 'testhost'
+        backup['host'] = host
         backup['availability_zone'] = 'az1'
         backup['display_name'] = display_name
         backup['display_description'] = display_description
@@ -251,6 +252,48 @@ class BackupsAPITestCase(test.TestCase):
         db.backup_destroy(context.get_admin_context(), backup_id2)
         db.backup_destroy(context.get_admin_context(), backup_id1)
 
+    def test_list_backups_detail_using_filters(self):
+        backup_id1 = self._create_backup(display_name='test2')
+        backup_id2 = self._create_backup(status='available')
+        backup_id3 = self._create_backup(volume_id=4321)
+
+        req = webob.Request.blank('/v2/fake/backups/detail?name=test2')
+        req.method = 'GET'
+        req.headers['Content-Type'] = 'application/json'
+        req.headers['Accept'] = 'application/json'
+        res = req.get_response(fakes.wsgi_app())
+        res_dict = json.loads(res.body)
+
+        self.assertEqual(len(res_dict['backups']), 1)
+        self.assertEqual(res.status_int, 200)
+        self.assertEqual(res_dict['backups'][0]['id'], backup_id1)
+
+        req = webob.Request.blank('/v2/fake/backups/detail?status=available')
+        req.method = 'GET'
+        req.headers['Content-Type'] = 'application/json'
+        req.headers['Accept'] = 'application/json'
+        res = req.get_response(fakes.wsgi_app())
+        res_dict = json.loads(res.body)
+
+        self.assertEqual(len(res_dict['backups']), 1)
+        self.assertEqual(res.status_int, 200)
+        self.assertEqual(res_dict['backups'][0]['id'], backup_id2)
+
+        req = webob.Request.blank('/v2/fake/backups/detail?volume_id=4321')
+        req.method = 'GET'
+        req.headers['Content-Type'] = 'application/json'
+        req.headers['Accept'] = 'application/json'
+        res = req.get_response(fakes.wsgi_app())
+        res_dict = json.loads(res.body)
+
+        self.assertEqual(len(res_dict['backups']), 1)
+        self.assertEqual(res.status_int, 200)
+        self.assertEqual(res_dict['backups'][0]['id'], backup_id3)
+
+        db.backup_destroy(context.get_admin_context(), backup_id3)
+        db.backup_destroy(context.get_admin_context(), backup_id2)
+        db.backup_destroy(context.get_admin_context(), backup_id1)
+
     def test_list_backups_detail_xml(self):
         backup_id1 = self._create_backup()
         backup_id2 = self._create_backup()
@@ -512,10 +555,7 @@ class BackupsAPITestCase(test.TestCase):
         az_not_match = [{'availability_zone': "strange_az", 'host': test_host,
                          'disabled': 0, 'updated_at': timeutils.utcnow()}]
         #service disabled
-        disabled_service = [{'availability_zone': "fake_az",
-                             'host': test_host,
-                             'disabled': 1,
-                             'updated_at': timeutils.utcnow()}]
+        disabled_service = []
 
         #dead service that last reported at 20th century
         dead_service = [{'availability_zone': "fake_az", 'host': alt_host,
@@ -944,6 +984,33 @@ class BackupsAPITestCase(test.TestCase):
         db.volume_destroy(context.get_admin_context(), volume_id)
         db.backup_destroy(context.get_admin_context(), backup_id)
 
+    @mock.patch('cinder.backup.rpcapi.BackupAPI.restore_backup')
+    def test_restore_backup_with_different_host(self, mock_restore_backup):
+        backup_id = self._create_backup(status='available', size=10,
+                                        host='HostA@BackendB#PoolA')
+        volume_id = utils.create_volume(self.context, size=10,
+                                        host='HostB@BackendB#PoolB')['id']
+
+        body = {"restore": {"volume_id": volume_id, }}
+        req = webob.Request.blank('/v2/fake/backups/%s/restore' %
+                                  backup_id)
+        req.method = 'POST'
+        req.headers['Content-Type'] = 'application/json'
+        req.body = json.dumps(body)
+        res = req.get_response(fakes.wsgi_app())
+        res_dict = json.loads(res.body)
+
+        self.assertEqual(res.status_int, 202)
+        self.assertEqual(res_dict['restore']['backup_id'], backup_id)
+        self.assertEqual(res_dict['restore']['volume_id'], volume_id)
+        mock_restore_backup.assert_called_once_with(mock.ANY,
+                                                    'HostB',
+                                                    backup_id,
+                                                    volume_id)
+
+        db.volume_destroy(context.get_admin_context(), volume_id)
+        db.backup_destroy(context.get_admin_context(), backup_id)
+
     def test_export_record_as_non_admin(self):
         backup_id = self._create_backup(status='available', size=10)
         req = webob.Request.blank('/v2/fake/backups/%s/export_record' %
