@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 Justin Santa Barbara
 # Copyright 2012 OpenStack Foundation
 # All Rights Reserved.
@@ -231,8 +229,6 @@ def FakeImageService_reset():
 
 
 def stub_out_image_service(stubs):
-    def fake_get_remote_image_service(context, image_href):
-        return (FakeImageService(), image_href)
     stubs.Set(cinder.image.glance, 'get_remote_image_service',
               lambda x, y: (FakeImageService(), y))
     stubs.Set(cinder.image.glance, 'get_default_image_service',
