@@ -1,4 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
 # Copyright 2012 OpenStack Foundation
 # All Rights Reserved.
@@ -25,8 +24,8 @@ from cinder import exception
 from cinder.image import image_utils
 from cinder.openstack.common import jsonutils
 from cinder.openstack.common import log as logging
+from cinder.openstack.common import units
 from cinder import test
-from cinder import units
 from cinder import utils
 from cinder.volume import configuration as conf
 from cinder.volume.drivers import coraid
@@ -38,7 +37,7 @@ LOG = logging.getLogger(__name__)
 
 
 def to_coraid_kb(gb):
-    return math.ceil(float(gb) * units.GiB / 1000)
+    return math.ceil(float(gb) * units.Gi / 1000)
 
 
 def coraid_volume_size(gb):
@@ -67,7 +66,8 @@ fake_lun_addr = {"shelf": fake_shelf, "lun": fake_lun}
 
 fake_volume_type = {'id': 1}
 
-fake_volume = {"name": fake_volume_name,
+fake_volume = {"id": fake_volume_name,
+               "name": fake_volume_name,
                "size": fake_volume_size,
                "volume_type": fake_volume_type}
 
@@ -231,9 +231,6 @@ class FakeRpc(object):
 class CoraidDriverTestCase(test.TestCase):
     def setUp(self):
         super(CoraidDriverTestCase, self).setUp()
-
-        self.mox = mox.Mox()
-
         configuration = mox.MockObject(conf.Configuration)
         configuration.append_config_values(mox.IgnoreArg())
         configuration.coraid_esm_address = fake_esm_ipaddress
@@ -245,6 +242,7 @@ class CoraidDriverTestCase(test.TestCase):
         configuration.coraid_repository_key = fake_coraid_repository_key
         configuration.use_multipath_for_image_xfer = False
         configuration.num_volume_device_scan_tries = 3
+        configuration.volume_dd_blocksize = '1M'
         self.fake_rpc = FakeRpc()
 
         self.stubs.Set(coraid.CoraidRESTClient, 'rpc', self.fake_rpc)
@@ -252,11 +250,7 @@ class CoraidDriverTestCase(test.TestCase):
         self.driver = coraid.CoraidDriver(configuration=configuration)
         self.driver.do_setup({})
 
-    def tearDown(self):
-        self.mox.UnsetStubs()
-        super(CoraidDriverTestCase, self).tearDown()
-
-    def mock_volume_types(self, repositories=[]):
+    def mock_volume_types(self, repositories=None):
         if not repositories:
             repositories = [fake_repository_name]
         self.mox.StubOutWithMock(volume_types, 'get_volume_type_extra_specs')
@@ -495,7 +489,8 @@ class CoraidDriverIntegrationalTestCase(CoraidDriverLoginSuccessTestCase):
         delete_snapshot_request = {'addr': 'cms',
                                    'data': {
                                        'repoName': fake_repository_name,
-                                       'lvName': fake_snapshot_name},
+                                       'lvName': fake_snapshot_name,
+                                       'newLvName': 'noop'},
                                    'op': 'orchStrLunMods',
                                    'args': 'delClSnap'}
         pack_data(delete_snapshot_request)
@@ -676,18 +671,12 @@ class CoraidDriverIntegrationalTestCase(CoraidDriverLoginSuccessTestCase):
 class AutoReloginCoraidTestCase(test.TestCase):
     def setUp(self):
         super(AutoReloginCoraidTestCase, self).setUp()
-        self.mox = mox.Mox()
-
         self.rest_client = coraid.CoraidRESTClient('https://fake')
         self.appliance = coraid.CoraidAppliance(self.rest_client,
                                                 'fake_username',
                                                 'fake_password',
                                                 'fake_group')
 
-    def tearDown(self):
-        self.mox.UnsetStubs()
-        super(AutoReloginCoraidTestCase, self).tearDown()
-
     def _test_auto_relogin_fail(self, state):
         self.mox.StubOutWithMock(self.rest_client, 'rpc')
 
@@ -771,8 +760,8 @@ class CoraidDriverImageTestCases(CoraidDriverTestCase):
             .AndReturn(self.fake_connection)
 
         self.mox.StubOutWithMock(self.driver, 'terminate_connection')
-        self.driver.terminate_connection(fake_volume, mox.IgnoreArg())\
-            .AndReturn(None)
+        self.driver.terminate_connection(fake_volume, mox.IgnoreArg(),
+                                         force=False).AndReturn(None)
 
         root_helper = 'sudo cinder-rootwrap /etc/cinder/rootwrap.conf'
 
@@ -829,6 +818,7 @@ class CoraidDriverImageTestCases(CoraidDriverTestCase):
                                  fake_image_service,
                                  fake_image_id,
                                  self.fake_dev_path,
+                                 mox.IgnoreArg(),
                                  size=fake_volume_size)
 
         self.mox.ReplayAll()
