@@ -19,14 +19,14 @@ Unit Tests for Huawei HVS volume drivers.
 """
 
 import json
-import mox
 import os
 import shutil
 import tempfile
 import time
-
 from xml.dom.minidom import Document
 
+import mox
+
 from cinder import exception
 from cinder import test
 from cinder.volume import configuration as conf
@@ -115,13 +115,13 @@ class FakeHVSCommon(rest_common.HVSCommon):
 
         if self.test_normal:
             if url == "/xx/sessions":
-                    data = """{"error":{"code":0},
-                                "data":{"username":"admin",
-                                        "deviceid":"210235G7J20000000000"
-                                       }}"""
+                data = """{"error":{"code":0},
+                            "data":{"username":"admin",
+                                    "deviceid":"210235G7J20000000000"
+                                   }}"""
             if url == "sessions":
-                    data = """{"error":{"code":0},
-                                "data":{"ID":11}}"""
+                data = """{"error":{"code":0},
+                            "data":{"ID":11}}"""
 
             if url == "storagepool":
                 data = """{"error":{"code":0},
@@ -504,7 +504,10 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
     def setUp(self):
         super(HVSRESTiSCSIDriverTestCase, self).setUp()
         self.tmp_dir = tempfile.mkdtemp()
+        self.addCleanup(shutil.rmtree, self.tmp_dir)
         self.fake_conf_file = self.tmp_dir + '/cinder_huawei_conf.xml'
+        self.addCleanup(os.remove, self.fake_conf_file)
+
         self.create_fake_conf_file()
         self.configuration = mox.MockObject(conf.Configuration)
         self.configuration.cinder_huawei_conf_file = self.fake_conf_file
@@ -517,12 +520,6 @@ class HVSRESTiSCSIDriverTestCase(test.TestCase):
         self.driver.do_setup({})
         self.driver.common.test_normal = True
 
-    def tearDown(self):
-        if os.path.exists(self.fake_conf_file):
-            os.remove(self.fake_conf_file)
-        shutil.rmtree(self.tmp_dir)
-        super(HVSRESTiSCSIDriverTestCase, self).tearDown()
-
     def test_log_in_success(self):
         deviceid = self.driver.common.login()
         self.assertIsNotNone(deviceid)
@@ -699,7 +696,10 @@ class HVSRESTFCDriverTestCase(test.TestCase):
     def setUp(self):
         super(HVSRESTFCDriverTestCase, self).setUp()
         self.tmp_dir = tempfile.mkdtemp()
+        self.addCleanup(shutil.rmtree, self.tmp_dir)
         self.fake_conf_file = self.tmp_dir + '/cinder_huawei_conf.xml'
+        self.addCleanup(os.remove, self.fake_conf_file)
+
         self.create_fake_conf_file()
         self.configuration = mox.MockObject(conf.Configuration)
         self.configuration.cinder_huawei_conf_file = self.fake_conf_file
@@ -711,12 +711,6 @@ class HVSRESTFCDriverTestCase(test.TestCase):
         self.driver.do_setup({})
         self.driver.common.test_normal = True
 
-    def tearDown(self):
-        if os.path.exists(self.fake_conf_file):
-            os.remove(self.fake_conf_file)
-        shutil.rmtree(self.tmp_dir)
-        super(HVSRESTFCDriverTestCase, self).tearDown()
-
     def test_log_in_Success(self):
         deviceid = self.driver.common.login()
         self.assertIsNotNone(deviceid)
