@@ -34,6 +34,8 @@ class TargetAdminTestCase(object):
         self.path = '/foo'
         self.vol_id = 'blaa'
         self.vol_name = 'volume-blaa'
+        self.chap_username = 'test_id'
+        self.chap_password = 'test_pass'
         self.write_cache = 'off'
         self.db = {}
 
@@ -66,7 +68,9 @@ class TargetAdminTestCase(object):
         return {'tid': self.tid,
                 'target_name': self.target_name,
                 'lun': self.lun,
-                'path': self.path}
+                'path': self.path,
+                'username': self.chap_username,
+                'password': self.chap_password}
 
     def get_script(self):
         return self.script_template % self.get_script_params()
@@ -78,10 +82,14 @@ class TargetAdminTestCase(object):
     def clear_cmds(self):
         self.cmds = []
 
+    def verify_config(self):
+        pass
+
     def verify_cmds(self, cmds):
         self.assertEqual(len(cmds), len(self.cmds))
         for cmd in self.cmds:
             self.assertTrue(cmd in cmds)
+        self.verify_config()
 
     def verify(self):
         script = self.get_script()
@@ -95,8 +103,11 @@ class TargetAdminTestCase(object):
     def run_commands(self):
         target_helper = self.driver.get_target_helper(self.db)
         target_helper.set_execute(self.fake_execute)
+        chap_auth = target_helper._iscsi_authentication('IncomingUser',
+                                                        self.chap_username,
+                                                        self.chap_password)
         target_helper.create_iscsi_target(self.target_name, self.tid,
-                                          self.lun, self.path,
+                                          self.lun, self.path, chap_auth,
                                           write_cache=self.write_cache)
         target_helper.show_target(self.tid, iqn=self.target_name)
         target_helper.remove_iscsi_target(self.tid, self.lun, self.vol_id,
@@ -128,6 +139,11 @@ class TgtAdmTestCase(test.TestCase, TargetAdminTestCase):
             '--delete %(target_name)s',
             'tgtadm --lld iscsi --op show --mode target'])
 
+    def verify_config(self):
+        target_helper = self.driver.get_target_helper(self.db)
+        self.assertEqual(target_helper._get_target_chap_auth(self.target_name),
+                         (self.chap_username, self.chap_password))
+
 
 class IetAdmTestCase(test.TestCase, TargetAdminTestCase):
 
@@ -139,6 +155,8 @@ class IetAdmTestCase(test.TestCase, TargetAdminTestCase):
             'ietadm --op new --tid=%(tid)s --params Name=%(target_name)s',
             'ietadm --op new --tid=%(tid)s --lun=%(lun)s '
             '--params Path=%(path)s,Type=fileio',
+            'ietadm --op new --tid=%(tid)s --user '
+            '--params=IncomingUser=%(username)s,Password=%(password)s',
             'ietadm --op show --tid=%(tid)s',
             'ietadm --op delete --tid=%(tid)s --lun=%(lun)s',
             'ietadm --op delete --tid=%(tid)s'])
@@ -155,6 +173,8 @@ class IetAdmBlockIOTestCase(test.TestCase, TargetAdminTestCase):
             'ietadm --op new --tid=%(tid)s --params Name=%(target_name)s',
             'ietadm --op new --tid=%(tid)s --lun=%(lun)s '
             '--params Path=%(path)s,Type=blockio',
+            'ietadm --op new --tid=%(tid)s --user '
+            '--params=IncomingUser=%(username)s,Password=%(password)s',
             'ietadm --op show --tid=%(tid)s',
             'ietadm --op delete --tid=%(tid)s --lun=%(lun)s',
             'ietadm --op delete --tid=%(tid)s'])
@@ -171,6 +191,8 @@ class IetAdmFileIOTestCase(test.TestCase, TargetAdminTestCase):
             'ietadm --op new --tid=%(tid)s --params Name=%(target_name)s',
             'ietadm --op new --tid=%(tid)s --lun=%(lun)s '
             '--params Path=%(path)s,Type=fileio',
+            'ietadm --op new --tid=%(tid)s --user '
+            '--params=IncomingUser=%(username)s,Password=%(password)s',
             'ietadm --op show --tid=%(tid)s',
             'ietadm --op delete --tid=%(tid)s --lun=%(lun)s',
             'ietadm --op delete --tid=%(tid)s'])
@@ -188,6 +210,8 @@ class IetAdmAutoIOTestCase(test.TestCase, TargetAdminTestCase):
             'ietadm --op new --tid=%(tid)s --params Name=%(target_name)s',
             'ietadm --op new --tid=%(tid)s --lun=%(lun)s '
             '--params Path=%(path)s,Type=blockio',
+            'ietadm --op new --tid=%(tid)s --user '
+            '--params=IncomingUser=%(username)s,Password=%(password)s',
             'ietadm --op show --tid=%(tid)s',
             'ietadm --op delete --tid=%(tid)s --lun=%(lun)s',
             'ietadm --op delete --tid=%(tid)s'])
@@ -201,7 +225,7 @@ class LioAdmTestCase(test.TestCase, TargetAdminTestCase):
         self.flags(iscsi_helper='lioadm')
         self.script_template = "\n".join([
             'cinder-rtstool create '
-            '%(path)s %(target_name)s test_id test_pass',
+            '%(path)s %(target_name)s %(username)s %(password)s',
             'cinder-rtstool delete %(target_name)s'])
 
 
