@@ -21,6 +21,7 @@ import datetime
 import mock
 from oslo.config import cfg
 
+from cinder import backup
 from cinder import context
 from cinder import db
 from cinder.db.sqlalchemy import api as sqa_api
@@ -44,10 +45,14 @@ class QuotaIntegrationTestCase(test.TestCase):
         self.volume_type = db.volume_type_create(
             context.get_admin_context(),
             dict(name=self.volume_type_name))
+        self.addCleanup(db.volume_type_destroy, context.get_admin_context(),
+                        self.volume_type['id'])
 
         self.flags(quota_volumes=2,
                    quota_snapshots=2,
-                   quota_gigabytes=20)
+                   quota_gigabytes=20,
+                   quota_backups=2,
+                   quota_backup_gigabytes=20)
 
         self.user_id = 'admin'
         self.project_id = 'admin'
@@ -59,12 +64,7 @@ class QuotaIntegrationTestCase(test.TestCase):
         # conflicts with the test cases here that are setting up their own
         # defaults.
         db.quota_class_destroy_all_by_name(self.context, 'default')
-
-    def tearDown(self):
-        db.volume_type_destroy(context.get_admin_context(),
-                               self.volume_type['id'])
-        super(QuotaIntegrationTestCase, self).tearDown()
-        cinder.tests.image.fake.FakeImageService_reset()
+        self.addCleanup(cinder.tests.image.fake.FakeImageService_reset)
 
     def _create_volume(self, size=1):
         """Create a test volume."""
@@ -74,6 +74,7 @@ class QuotaIntegrationTestCase(test.TestCase):
         vol['size'] = size
         vol['status'] = 'available'
         vol['volume_type_id'] = self.volume_type['id']
+        vol['host'] = 'fake_host'
         return db.volume_create(self.context, vol)
 
     def _create_snapshot(self, volume):
@@ -82,9 +83,19 @@ class QuotaIntegrationTestCase(test.TestCase):
         snapshot['project_id'] = self.project_id
         snapshot['volume_id'] = volume['id']
         snapshot['volume_size'] = volume['size']
+        snapshot['host'] = volume['host']
         snapshot['status'] = 'available'
         return db.snapshot_create(self.context, snapshot)
 
+    def _create_backup(self, volume):
+        backup = {}
+        backup['user_id'] = self.user_id
+        backup['project_id'] = self.project_id
+        backup['volume_id'] = volume['id']
+        backup['volume_size'] = volume['size']
+        backup['status'] = 'available'
+        return db.backup_create(self.context, backup)
+
     def test_too_many_volumes(self):
         volume_ids = []
         for i in range(CONF.quota_volumes):
@@ -128,6 +139,29 @@ class QuotaIntegrationTestCase(test.TestCase):
         db.snapshot_destroy(self.context, snap_ref['id'])
         db.volume_destroy(self.context, vol_ref['id'])
 
+    def test_too_many_backups(self):
+        resource = 'backups'
+        db.quota_class_create(self.context, 'default', resource, 1)
+        flag_args = {
+            'quota_backups': 2000,
+            'quota_backup_gigabytes': 2000
+        }
+        self.flags(**flag_args)
+        vol_ref = self._create_volume()
+        backup_ref = self._create_backup(vol_ref)
+        with mock.patch.object(backup.API, '_is_backup_service_enabled') as \
+                mock__is_backup_service_enabled:
+            mock__is_backup_service_enabled.return_value = True
+            self.assertRaises(exception.BackupLimitExceeded,
+                              backup.API().create,
+                              self.context,
+                              'name',
+                              'description',
+                              vol_ref['id'],
+                              'container')
+            db.backup_destroy(self.context, backup_ref['id'])
+            db.volume_destroy(self.context, vol_ref['id'])
+
     def test_too_many_gigabytes(self):
         volume_ids = []
         vol_ref = self._create_volume(size=20)
@@ -151,6 +185,23 @@ class QuotaIntegrationTestCase(test.TestCase):
         db.snapshot_destroy(self.context, snap_ref['id'])
         db.volume_destroy(self.context, vol_ref['id'])
 
+    def test_too_many_combined_backup_gigabytes(self):
+        vol_ref = self._create_volume(size=10000)
+        backup_ref = self._create_backup(vol_ref)
+        with mock.patch.object(backup.API, '_is_backup_service_enabled') as \
+                mock__is_backup_service_enabled:
+            mock__is_backup_service_enabled.return_value = True
+            self.assertRaises(
+                exception.VolumeBackupSizeExceedsAvailableQuota,
+                backup.API().create,
+                context=self.context,
+                name='name',
+                description='description',
+                volume_id=vol_ref['id'],
+                container='container')
+            db.backup_destroy(self.context, backup_ref['id'])
+            db.volume_destroy(self.context, vol_ref['id'])
+
     def test_no_snapshot_gb_quota_flag(self):
         self.flags(quota_volumes=2,
                    quota_snapshots=2,
@@ -161,22 +212,47 @@ class QuotaIntegrationTestCase(test.TestCase):
         snap_ref2 = volume.API().create_snapshot(self.context,
                                                  vol_ref, '', '')
 
-        # Make sure no reservation was created for snapshot gigabytes.
-        reservations = db.reservation_get_all_by_project(self.context,
-                                                         self.project_id)
-        self.assertIsNone(reservations.get('gigabytes'))
-
         # Make sure the snapshot volume_size isn't included in usage.
         vol_ref2 = volume.API().create(self.context, 10, '', '')
         usages = db.quota_usage_get_all_by_project(self.context,
                                                    self.project_id)
         self.assertEqual(usages['gigabytes']['in_use'], 20)
+        self.assertEqual(usages['gigabytes']['reserved'], 0)
 
         db.snapshot_destroy(self.context, snap_ref['id'])
         db.snapshot_destroy(self.context, snap_ref2['id'])
         db.volume_destroy(self.context, vol_ref['id'])
         db.volume_destroy(self.context, vol_ref2['id'])
 
+    def test_backup_gb_quota_flag(self):
+        self.flags(quota_volumes=2,
+                   quota_snapshots=2,
+                   quota_backups=2,
+                   quota_gigabytes=20
+                   )
+        vol_ref = self._create_volume(size=10)
+        backup_ref = self._create_backup(vol_ref)
+        with mock.patch.object(backup.API, '_is_backup_service_enabled') as \
+                mock__is_backup_service_enabled:
+            mock__is_backup_service_enabled.return_value = True
+            backup_ref2 = backup.API().create(self.context,
+                                              'name',
+                                              'description',
+                                              vol_ref['id'],
+                                              'container')
+
+            # Make sure the backup volume_size isn't included in usage.
+            vol_ref2 = volume.API().create(self.context, 10, '', '')
+            usages = db.quota_usage_get_all_by_project(self.context,
+                                                       self.project_id)
+            self.assertEqual(usages['gigabytes']['in_use'], 20)
+            self.assertEqual(usages['gigabytes']['reserved'], 0)
+
+            db.backup_destroy(self.context, backup_ref['id'])
+            db.backup_destroy(self.context, backup_ref2['id'])
+            db.volume_destroy(self.context, vol_ref['id'])
+            db.volume_destroy(self.context, vol_ref2['id'])
+
     def test_too_many_gigabytes_of_type(self):
         resource = 'gigabytes_%s' % self.volume_type_name
         db.quota_class_create(self.context, 'default', resource, 10)
@@ -684,7 +760,8 @@ class VolumeTypeQuotaEngineTestCase(test.TestCase):
 
         engine = quota.VolumeTypeQuotaEngine()
         self.assertEqual(engine.resource_names,
-                         ['gigabytes', 'snapshots', 'volumes'])
+                         ['backup_gigabytes', 'backups',
+                          'gigabytes', 'snapshots', 'volumes'])
 
     def test_volume_type_resources(self):
         ctx = context.RequestContext('admin', 'admin', is_admin=True)
@@ -708,7 +785,8 @@ class VolumeTypeQuotaEngineTestCase(test.TestCase):
 
         engine = quota.VolumeTypeQuotaEngine()
         self.assertEqual(engine.resource_names,
-                         ['gigabytes', 'gigabytes_type1', 'gigabytes_type_2',
+                         ['backup_gigabytes', 'backups',
+                          'gigabytes', 'gigabytes_type1', 'gigabytes_type_2',
                           'snapshots', 'snapshots_type1', 'snapshots_type_2',
                           'volumes', 'volumes_type1', 'volumes_type_2'])
         db.volume_type_destroy(ctx, vtype['id'])
@@ -722,6 +800,8 @@ class DbQuotaDriverTestCase(test.TestCase):
         self.flags(quota_volumes=10,
                    quota_snapshots=10,
                    quota_gigabytes=1000,
+                   quota_backups=10,
+                   quota_backup_gigabytes=1000,
                    reservation_expire=86400,
                    until_refresh=0,
                    max_age=0,
@@ -747,7 +827,9 @@ class DbQuotaDriverTestCase(test.TestCase):
             dict(
                 volumes=10,
                 snapshots=10,
-                gigabytes=1000, ))
+                gigabytes=1000,
+                backups=10,
+                backup_gigabytes=1000))
 
     def _stub_quota_class_get_default(self):
         # Stub out quota_class_get_default
@@ -755,7 +837,10 @@ class DbQuotaDriverTestCase(test.TestCase):
             self.calls.append('quota_class_get_default')
             return dict(volumes=10,
                         snapshots=10,
-                        gigabytes=1000,)
+                        gigabytes=1000,
+                        backups=10,
+                        backup_gigabytes=1000
+                        )
         self.stubs.Set(db, 'quota_class_get_default', fake_qcgd)
 
     def _stub_volume_type_get_all(self):
@@ -768,7 +853,8 @@ class DbQuotaDriverTestCase(test.TestCase):
         def fake_qcgabn(context, quota_class):
             self.calls.append('quota_class_get_all_by_name')
             self.assertEqual(quota_class, 'test_class')
-            return dict(gigabytes=500, volumes=10, snapshots=10, )
+            return dict(gigabytes=500, volumes=10, snapshots=10, backups=10,
+                        backup_gigabytes=500)
         self.stubs.Set(db, 'quota_class_get_all_by_name', fake_qcgabn)
 
     def test_get_class_quotas(self):
@@ -780,7 +866,9 @@ class DbQuotaDriverTestCase(test.TestCase):
         self.assertEqual(self.calls, ['quota_class_get_all_by_name'])
         self.assertEqual(result, dict(volumes=10,
                                       gigabytes=500,
-                                      snapshots=10))
+                                      snapshots=10,
+                                      backups=10,
+                                      backup_gigabytes=500))
 
     def test_get_class_quotas_no_defaults(self):
         self._stub_quota_class_get_all_by_name()
@@ -790,20 +878,27 @@ class DbQuotaDriverTestCase(test.TestCase):
         self.assertEqual(self.calls, ['quota_class_get_all_by_name'])
         self.assertEqual(result, dict(volumes=10,
                                       gigabytes=500,
-                                      snapshots=10))
+                                      snapshots=10,
+                                      backups=10,
+                                      backup_gigabytes=500))
 
     def _stub_get_by_project(self):
         def fake_qgabp(context, project_id):
             self.calls.append('quota_get_all_by_project')
             self.assertEqual(project_id, 'test_project')
-            return dict(volumes=10, gigabytes=50, reserved=0, snapshots=10)
+            return dict(volumes=10, gigabytes=50, reserved=0,
+                        snapshots=10, backups=10,
+                        backup_gigabytes=50)
 
         def fake_qugabp(context, project_id):
             self.calls.append('quota_usage_get_all_by_project')
             self.assertEqual(project_id, 'test_project')
             return dict(volumes=dict(in_use=2, reserved=0),
                         snapshots=dict(in_use=2, reserved=0),
-                        gigabytes=dict(in_use=10, reserved=0), )
+                        gigabytes=dict(in_use=10, reserved=0),
+                        backups=dict(in_use=2, reserved=0),
+                        backup_gigabytes=dict(in_use=10, reserved=0)
+                        )
 
         self.stubs.Set(db, 'quota_get_all_by_project', fake_qgabp)
         self.stubs.Set(db, 'quota_usage_get_all_by_project', fake_qugabp)
@@ -830,7 +925,14 @@ class DbQuotaDriverTestCase(test.TestCase):
                                                      reserved=0, ),
                                       gigabytes=dict(limit=50,
                                                      in_use=10,
-                                                     reserved=0, ), ))
+                                                     reserved=0, ),
+                                      backups=dict(limit=10,
+                                                   in_use=2,
+                                                   reserved=0, ),
+                                      backup_gigabytes=dict(limit=50,
+                                                            in_use=10,
+                                                            reserved=0, ),
+                                      ))
 
     def test_get_project_quotas_alt_context_no_class(self):
         self._stub_get_by_project()
@@ -850,7 +952,14 @@ class DbQuotaDriverTestCase(test.TestCase):
                                                      reserved=0, ),
                                       gigabytes=dict(limit=50,
                                                      in_use=10,
-                                                     reserved=0, ), ))
+                                                     reserved=0, ),
+                                      backups=dict(limit=10,
+                                                   in_use=2,
+                                                   reserved=0, ),
+                                      backup_gigabytes=dict(limit=50,
+                                                            in_use=10,
+                                                            reserved=0, ),
+                                      ))
 
     def test_get_project_quotas_alt_context_with_class(self):
         self._stub_get_by_project()
@@ -871,7 +980,14 @@ class DbQuotaDriverTestCase(test.TestCase):
                                                      reserved=0, ),
                                       gigabytes=dict(limit=50,
                                                      in_use=10,
-                                                     reserved=0, ), ))
+                                                     reserved=0, ),
+                                      backups=dict(limit=10,
+                                                   in_use=2,
+                                                   reserved=0, ),
+                                      backup_gigabytes=dict(limit=50,
+                                                            in_use=10,
+                                                            reserved=0, ),
+                                      ))
 
     def test_get_project_quotas_no_defaults(self):
         self._stub_get_by_project()
@@ -885,7 +1001,13 @@ class DbQuotaDriverTestCase(test.TestCase):
                                       'quota_class_get_all_by_name',
                                       'quota_class_get_default', ])
         self.assertEqual(result,
-                         dict(gigabytes=dict(limit=50,
+                         dict(backups=dict(limit=10,
+                                           in_use=2,
+                                           reserved=0, ),
+                              backup_gigabytes=dict(limit=50,
+                                                    in_use=10,
+                                                    reserved=0, ),
+                              gigabytes=dict(limit=50,
                                              in_use=10,
                                              reserved=0, ),
                               snapshots=dict(limit=10,
@@ -893,7 +1015,9 @@ class DbQuotaDriverTestCase(test.TestCase):
                                              reserved=0, ),
                               volumes=dict(limit=10,
                                            in_use=2,
-                                           reserved=0, ), ))
+                                           reserved=0, ),
+
+                              ))
 
     def test_get_project_quotas_no_usages(self):
         self._stub_get_by_project()
@@ -907,7 +1031,9 @@ class DbQuotaDriverTestCase(test.TestCase):
                                       'quota_class_get_default', ])
         self.assertEqual(result, dict(volumes=dict(limit=10, ),
                                       snapshots=dict(limit=10, ),
-                                      gigabytes=dict(limit=50, ), ))
+                                      backups=dict(limit=10, ),
+                                      gigabytes=dict(limit=50, ),
+                                      backup_gigabytes=dict(limit=50, ),))
 
     def _stub_get_project_quotas(self):
         def fake_get_project_quotas(context, resources, project_id,
