@@ -19,13 +19,13 @@
 import os.path
 import re
 import socket
+import ssl
 import tempfile
 import time
 import urllib2
 
 import mock
 from oslo.config import cfg
-from oslo_i18n import fixture as i18n_fixture
 import testtools
 import webob
 import webob.dec
@@ -42,7 +42,17 @@ TEST_VAR_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__),
 
 
 def open_no_proxy(*args, **kwargs):
-    opener = urllib2.build_opener(urllib2.ProxyHandler({}))
+    # NOTE(coreycb):
+    # Deal with more secure certification chain verficiation
+    # introduced in python 2.7.9 under PEP-0476
+    # https://github.com/python/peps/blob/master/pep-0476.txt
+    if hasattr(ssl, "_create_unverified_context"):
+        opener = urllib2.build_opener(
+            urllib2.ProxyHandler({}),
+            urllib2.HTTPSHandler(context=ssl._create_unverified_context())
+        )
+    else:
+        opener = urllib2.build_opener(urllib2.ProxyHandler({}))
     return opener.open(*args, **kwargs)
 
 
@@ -256,7 +266,6 @@ class ExceptionTest(test.TestCase):
 
     def setUp(self):
         super(ExceptionTest, self).setUp()
-        self.useFixture(i18n_fixture.ToggleLazy(True))
 
     def _wsgi_app(self, inner_app):
         # NOTE(luisg): In order to test localization, we need to
