@@ -15,7 +15,6 @@
 #    under the License.
 """
 Drivers for volumes.
-
 """
 
 import time
@@ -23,6 +22,7 @@ import time
 from oslo.config import cfg
 
 from cinder import exception
+from cinder.i18n import _
 from cinder.image import image_utils
 from cinder.openstack.common import excutils
 from cinder.openstack.common import fileutils
@@ -38,16 +38,16 @@ LOG = logging.getLogger(__name__)
 volume_opts = [
     cfg.IntOpt('num_shell_tries',
                default=3,
-               help='number of times to attempt to run flakey shell commands'),
+               help='Number of times to attempt to run flakey shell commands'),
     cfg.IntOpt('reserved_percentage',
                default=0,
                help='The percentage of backend capacity is reserved'),
     cfg.IntOpt('iscsi_num_targets',
                default=100,
-               help='The maximum number of iscsi target ids per host'),
+               help='The maximum number of iSCSI target IDs per host'),
     cfg.StrOpt('iscsi_target_prefix',
                default='iqn.2010-10.org.openstack:',
-               help='prefix for iscsi volumes'),
+               help='Prefix for iSCSI volumes'),
     cfg.StrOpt('iscsi_ip_address',
                default='$my_ip',
                help='The IP address that the iSCSI daemon is listening on'),
@@ -68,7 +68,7 @@ volume_opts = [
                      'for volume to image and image to volume transfers?'),
     cfg.StrOpt('volume_clear',
                default='zero',
-               help='Method used to wipe old voumes (valid options are: '
+               help='Method used to wipe old volumes (valid options are: '
                     'none, zero, shred)'),
     cfg.IntOpt('volume_clear_size',
                default=0,
@@ -80,7 +80,9 @@ volume_opts = [
                     'for example "-c3" for idle only priority.'),
     cfg.StrOpt('iscsi_helper',
                default='tgtadm',
-               help='iscsi target user-land tool to use'),
+               help='iSCSI target user-land tool to use. tgtadm is default, '
+                    'use lioadm for LIO iSCSI support, iseradm for the ISER '
+                    'protocol, or fake for testing.'),
     cfg.StrOpt('volumes_dir',
                default='$state_path/volumes',
                help='Volume configuration file storage '
@@ -103,6 +105,28 @@ volume_opts = [
                default='1M',
                help='The default block size used when copying/clearing '
                     'volumes'),
+    cfg.StrOpt('volume_copy_blkio_cgroup_name',
+               default='cinder-volume-copy',
+               help='The blkio cgroup name to be used to limit bandwidth '
+                    'of volume copy'),
+    cfg.IntOpt('volume_copy_bps_limit',
+               default=0,
+               help='The upper limit of bandwidth of volume copy. '
+                    '0 => unlimited'),
+    cfg.StrOpt('iscsi_write_cache',
+               default='on',
+               help='Sets the behavior of the iSCSI target to either '
+                    'perform write-back(on) or write-through(off). '
+                    'This parameter is valid if iscsi_helper is set '
+                    'to tgtadm or iseradm.'),
+    cfg.StrOpt('driver_client_cert_key',
+               default=None,
+               help='The path to the client certificate key for verification, '
+                    'if the driver supports it.'),
+    cfg.StrOpt('driver_client_cert',
+               default=None,
+               help='The path to the client certificate for verification, '
+                    'if the driver supports it.'),
 ]
 
 # for backward compatibility
@@ -113,10 +137,10 @@ iser_opts = [
                     'to find volume'),
     cfg.IntOpt('iser_num_targets',
                default=100,
-               help='The maximum number of iser target ids per host'),
+               help='The maximum number of iSER target IDs per host'),
     cfg.StrOpt('iser_target_prefix',
-               default='iqn.2010-10.org.openstack:',
-               help='prefix for iser volumes'),
+               default='iqn.2010-10.org.iser.openstack:',
+               help='Prefix for iSER volumes'),
     cfg.StrOpt('iser_ip_address',
                default='$my_ip',
                help='The IP address that the iSER daemon is listening on'),
@@ -125,7 +149,7 @@ iser_opts = [
                help='The port that the iSER daemon is listening on'),
     cfg.StrOpt('iser_helper',
                default='tgtadm',
-               help='iser target user-land tool to use'),
+               help='The name of the iSER target user-land tool to use'),
 ]
 
 
@@ -135,7 +159,29 @@ CONF.register_opts(iser_opts)
 
 
 class VolumeDriver(object):
-    """Executes commands relating to Volumes."""
+    """Executes commands relating to Volumes.
+
+       Base Driver for Cinder Volume Control Path,
+       This includes supported/required implementation
+       for API calls.  Also provides *generic* implementation
+       of core features like cloning, copy_image_to_volume etc,
+       this way drivers that inherit from this base class and
+       don't offer their own impl can fall back on a general
+       solution here.
+
+       Key thing to keep in mind with this driver is that it's
+       intended that these drivers ONLY implement Control Path
+       details (create, delete, extend...), while transport or
+       data path related implementation should be a *member object*
+       that we call a connector.  The point here is that for example
+       don't allow the LVM driver to implement iSCSI methods, instead
+       call whatever connector it has configued via conf file
+       (iSCSI{LIO, TGT, IET}, FC, etc).
+
+       In the base class and for example the LVM driver we do this via a has-a
+       relationship and just provide an interface to the specific connector
+       methods.  How you do this in your own driver is of course up to you.
+    """
 
     VERSION = "N/A"
 
@@ -144,29 +190,18 @@ class VolumeDriver(object):
         self.db = kwargs.get('db')
         self.host = kwargs.get('host')
         self.configuration = kwargs.get('configuration', None)
+
         if self.configuration:
             self.configuration.append_config_values(volume_opts)
             self.configuration.append_config_values(iser_opts)
         self.set_execute(execute)
         self._stats = {}
 
+        self.pools = []
+
         # set True by manager after successful check_for_setup
         self._initialized = False
 
-    def set_execute(self, execute):
-        self._execute = execute
-
-    def set_initialized(self):
-        self._initialized = True
-
-    @property
-    def initialized(self):
-        return self._initialized
-
-    def get_version(self):
-        """Get the current version of this driver."""
-        return self.VERSION
-
     def _is_non_recoverable(self, err, non_recoverable_list):
         for item in non_recoverable_list:
             if item in err:
@@ -197,25 +232,113 @@ class VolumeDriver(object):
                                 "Try number %s"), tries)
                 time.sleep(tries ** 2)
 
+    def _detach_volume(self, context, attach_info, volume, properties,
+                       force=False, remote=False):
+        """Disconnect the volume from the host."""
+        # Use Brick's code to do attach/detach
+        connector = attach_info['connector']
+        connector.disconnect_volume(attach_info['conn']['data'],
+                                    attach_info['device'])
+
+        if remote:
+            # Call remote manager's terminate_connection which includes
+            # driver's terminate_connection and remove export
+            rpcapi = volume_rpcapi.VolumeAPI()
+            rpcapi.terminate_connection(context, volume, properties,
+                                        force=force)
+        else:
+            # Call local driver's terminate_connection and remove export.
+            # NOTE(avishay) This is copied from the manager's code - need to
+            # clean this up in the future.
+            try:
+                self.terminate_connection(volume, properties, force=force)
+            except Exception as err:
+                err_msg = (_('Unable to terminate volume connection: %(err)s')
+                           % {'err': err})
+                LOG.error(err_msg)
+                raise exception.VolumeBackendAPIException(data=err_msg)
+
+            try:
+                LOG.debug(("volume %s: removing export"), volume['id'])
+                self.remove_export(context, volume)
+            except Exception as ex:
+                LOG.exception(_("Error detaching volume %(volume)s, "
+                                "due to remove export failure."),
+                              {"volume": volume['id']})
+                raise exception.RemoveExportException(volume=volume['id'],
+                                                      reason=ex)
+
+    def set_execute(self, execute):
+        self._execute = execute
+
+    def set_initialized(self):
+        self._initialized = True
+
+    @property
+    def initialized(self):
+        return self._initialized
+
+    def get_version(self):
+        """Get the current version of this driver."""
+        return self.VERSION
+
     def check_for_setup_error(self):
         raise NotImplementedError()
 
     def create_volume(self, volume):
         """Creates a volume. Can optionally return a Dictionary of
         changes to the volume object to be persisted.
+
+        If volume_type extra specs includes
+        'capabilities:replication <is> True' the driver
+        needs to create a volume replica (secondary), and setup replication
+        between the newly created volume and the secondary volume.
+        Returned dictionary should include:
+            volume['replication_status'] = 'copying'
+            volume['replication_extended_status'] = driver specific value
+            volume['driver_data'] = driver specific value
+
         """
         raise NotImplementedError()
 
     def create_volume_from_snapshot(self, volume, snapshot):
-        """Creates a volume from a snapshot."""
+        """Creates a volume from a snapshot.
+
+        If volume_type extra specs includes 'replication: <is> True'
+        the driver needs to create a volume replica (secondary),
+        and setup replication between the newly created volume and
+        the secondary volume.
+        """
+
         raise NotImplementedError()
 
     def create_cloned_volume(self, volume, src_vref):
-        """Creates a clone of the specified volume."""
+        """Creates a clone of the specified volume.
+
+        If volume_type extra specs includes 'replication: <is> True' the
+        driver needs to create a volume replica (secondary)
+        and setup replication between the newly created volume
+        and the secondary volume.
+
+        """
+
+        raise NotImplementedError()
+
+    def create_replica_test_volume(self, volume, src_vref):
+        """Creates a test replica clone of the specified replicated volume.
+
+        Create a clone of the replicated (secondary) volume.
+
+        """
         raise NotImplementedError()
 
     def delete_volume(self, volume):
-        """Deletes a volume."""
+        """Deletes a volume.
+
+        If volume_type extra specs includes 'replication: <is> True'
+        then the driver needs to delete the volume replica too.
+
+        """
         raise NotImplementedError()
 
     def create_snapshot(self, snapshot):
@@ -229,54 +352,19 @@ class VolumeDriver(object):
     def local_path(self, volume):
         raise NotImplementedError()
 
-    def ensure_export(self, context, volume):
-        """Synchronously recreates an export for a volume."""
-        raise NotImplementedError()
-
-    def create_export(self, context, volume):
-        """Exports the volume. Can optionally return a Dictionary of changes
-        to the volume object to be persisted.
-        """
-        raise NotImplementedError()
-
-    def remove_export(self, context, volume):
-        """Removes an export for a volume."""
-        raise NotImplementedError()
-
-    def initialize_connection(self, volume, connector):
-        """Allow connection to connector and return connection info."""
-        raise NotImplementedError()
-
-    def terminate_connection(self, volume, connector, **kwargs):
-        """Disallow connection from connector"""
-        raise NotImplementedError()
-
-    def attach_volume(self, context, volume, instance_uuid, host_name,
-                      mountpoint):
-        """Callback for volume attached to instance or host."""
-        pass
-
-    def detach_volume(self, context, volume):
-        """Callback for volume detached."""
-        pass
-
     def get_volume_stats(self, refresh=False):
         """Return the current state of the volume service. If 'refresh' is
            True, run the update first.
+
+           For replication the following state should be reported:
+           replication_support = True (None or false disables replication)
+
         """
         return None
 
-    def do_setup(self, context):
-        """Any initialization the volume driver does while starting."""
-        pass
-
-    def validate_connector(self, connector):
-        """Fail if connector doesn't contain all the data needed by driver."""
-        pass
-
     def copy_volume_data(self, context, src_vol, dest_vol, remote=None):
         """Copy data from src_vol to dest_vol."""
-        LOG.debug(_('copy_data_between_volumes %(src)s -> %(dest)s.')
+        LOG.debug(('copy_data_between_volumes %(src)s -> %(dest)s.')
                   % {'src': src_vol['name'], 'dest': dest_vol['name']})
 
         properties = utils.brick_get_connector_properties()
@@ -310,6 +398,7 @@ class VolumeDriver(object):
                 self._detach_volume(context, dest_attach_info, dest_vol,
                                     properties, force=True, remote=dest_remote)
 
+        copy_error = True
         try:
             size_in_mb = int(src_vol['size']) * 1024    # vol size is in GB
             volume_utils.copy_volume(
@@ -320,9 +409,8 @@ class VolumeDriver(object):
             copy_error = False
         except Exception:
             with excutils.save_and_reraise_exception():
-                msg = _("Failed to copy volume %(src)s to %(dest)d")
+                msg = _("Failed to copy volume %(src)s to %(dest)s.")
                 LOG.error(msg % {'src': src_vol['id'], 'dest': dest_vol['id']})
-                copy_error = True
         finally:
             self._detach_volume(context, dest_attach_info, dest_vol,
                                 properties, force=copy_error,
@@ -333,7 +421,7 @@ class VolumeDriver(object):
 
     def copy_image_to_volume(self, context, volume, image_service, image_id):
         """Fetch the image from image_service and write it to the volume."""
-        LOG.debug(_('copy_image_to_volume %s.') % volume['name'])
+        LOG.debug(('copy_image_to_volume %s.') % volume['name'])
 
         properties = utils.brick_get_connector_properties()
         attach_info = self._attach_volume(context, volume, properties)
@@ -350,7 +438,7 @@ class VolumeDriver(object):
 
     def copy_volume_to_image(self, context, volume, image_service, image_meta):
         """Copy the volume to the specified image."""
-        LOG.debug(_('copy_volume_to_image %s.') % volume['name'])
+        LOG.debug(('copy_volume_to_image %s.') % volume['name'])
 
         properties = utils.brick_get_connector_properties()
         attach_info = self._attach_volume(context, volume, properties)
@@ -376,7 +464,7 @@ class VolumeDriver(object):
             # clean this up in the future.
             model_update = None
             try:
-                LOG.debug(_("Volume %s: creating export"), volume['id'])
+                LOG.debug(("Volume %s: creating export"), volume['id'])
                 model_update = self.create_export(context, volume)
                 if model_update:
                     volume = self.db.volume_update(context, volume['id'],
@@ -410,11 +498,11 @@ class VolumeDriver(object):
         use_multipath = self.configuration.use_multipath_for_image_xfer
         device_scan_attempts = self.configuration.num_volume_device_scan_tries
         protocol = conn['driver_volume_type']
-        connector = utils.brick_get_connector(protocol,
-                                              use_multipath=use_multipath,
-                                              device_scan_attempts=
-                                              device_scan_attempts,
-                                              conn=conn)
+        connector = utils.brick_get_connector(
+            protocol,
+            use_multipath=use_multipath,
+            device_scan_attempts=device_scan_attempts,
+            conn=conn)
         device = connector.connect_volume(conn['data'])
         host_device = device['path']
 
@@ -427,42 +515,6 @@ class VolumeDriver(object):
                                                       {'path': host_device}))
         return {'conn': conn, 'device': device, 'connector': connector}
 
-    def _detach_volume(self, context, attach_info, volume, properties,
-                       force=False, remote=False):
-        """Disconnect the volume from the host."""
-        # Use Brick's code to do attach/detach
-        connector = attach_info['connector']
-        connector.disconnect_volume(attach_info['conn']['data'],
-                                    attach_info['device'])
-
-        if remote:
-            # Call remote manager's terminate_connection which includes
-            # driver's terminate_connection and remove export
-            rpcapi = volume_rpcapi.VolumeAPI()
-            rpcapi.terminate_connection(context, volume, properties,
-                                        force=force)
-        else:
-            # Call local driver's terminate_connection and remove export.
-            # NOTE(avishay) This is copied from the manager's code - need to
-            # clean this up in the future.
-            try:
-                self.terminate_connection(volume, properties, force=force)
-            except Exception as err:
-                err_msg = (_('Unable to terminate volume connection: %(err)s')
-                           % {'err': err})
-                LOG.error(err_msg)
-                raise exception.VolumeBackendAPIException(data=err_msg)
-
-            try:
-                LOG.debug(_("volume %s: removing export"), volume['id'])
-                self.remove_export(context, volume)
-            except Exception as ex:
-                LOG.exception(_("Error detaching volume %(volume)s, "
-                                "due to remove export failure."),
-                              {"volume": volume['id']})
-                raise exception.RemoveExportException(volume=volume['id'],
-                                                      reason=ex)
-
     def clone_image(self, volume, image_location, image_id, image_meta):
         """Create a volume efficiently from an existing image.
 
@@ -488,7 +540,7 @@ class VolumeDriver(object):
         """Create a new backup from an existing volume."""
         volume = self.db.volume_get(context, backup['volume_id'])
 
-        LOG.debug(_('Creating a new backup for volume %s.') %
+        LOG.debug(('Creating a new backup for volume %s.') %
                   volume['name'])
 
         properties = utils.brick_get_connector_properties()
@@ -505,8 +557,8 @@ class VolumeDriver(object):
 
     def restore_backup(self, context, backup, volume, backup_service):
         """Restore an existing backup to a new or existing volume."""
-        LOG.debug(_('Restoring backup %(backup)s to '
-                    'volume %(volume)s.') %
+        LOG.debug(('Restoring backup %(backup)s to '
+                   'volume %(volume)s.') %
                   {'backup': backup['id'],
                    'volume': volume['name']})
 
@@ -547,7 +599,24 @@ class VolumeDriver(object):
     def retype(self, context, volume, new_type, diff, host):
         """Convert the volume to be of the new type.
 
-        Returns a boolean indicating whether the retype occurred.
+        Returns either:
+        A boolean indicating whether the retype occurred, or
+        A tuple (retyped, model_update) where retyped is a boolean
+        indicating if the retype occurred, and the model_update includes
+        changes for the volume db.
+        if diff['extra_specs'] includes 'replication' then:
+            if  ('True', _ ) then replication should be disabled:
+                Volume replica should be deleted
+                volume['replication_status'] should be changed to 'disabled'
+                volume['replication_extended_status'] = None
+                volume['replication_driver_data'] = None
+            if  (_, 'True') then replication should be enabled:
+                Volume replica (secondary) should be created, and replication
+                should be setup between the volume and the newly created
+                replica
+                volume['replication_status'] = 'copying'
+                volume['replication_extended_status'] = driver specific value
+                volume['replication_driver_data'] = driver specific value
 
         :param ctxt: Context
         :param volume: A dictionary describing the volume to migrate
@@ -557,7 +626,7 @@ class VolumeDriver(object):
                      host['host'] is its name, and host['capabilities'] is a
                      dictionary of its reported capabilities.
         """
-        return False
+        return False, None
 
     def accept_transfer(self, context, volume, new_user, new_project):
         """Accept the transfer of a volume for a new user/project."""
@@ -614,6 +683,151 @@ class VolumeDriver(object):
         """
         pass
 
+    def attach_volume(self, context, volume, instance_uuid, host_name,
+                      mountpoint):
+        """Callback for volume attached to instance or host."""
+        pass
+
+    def detach_volume(self, context, volume):
+        """Callback for volume detached."""
+        pass
+
+    def do_setup(self, context):
+        """Any initialization the volume driver does while starting."""
+        pass
+
+    def validate_connector(self, connector):
+        """Fail if connector doesn't contain all the data needed by driver."""
+        pass
+
+    @staticmethod
+    def validate_connector_has_setting(connector, setting):
+        pass
+
+    def reenable_replication(self, context, volume):
+        """Re-enable replication between the replica and primary volume.
+
+        This is used to re-enable/fix the replication between primary
+        and secondary. One use is as part of the fail-back process, when
+        you re-synchorize your old primary with the promoted volume
+        (the old replica).
+        Returns model_update for the volume to reflect the actions of the
+        driver.
+        The driver is expected to update the following entries:
+            'replication_status'
+            'replication_extended_status'
+            'replication_driver_data'
+        Possible 'replication_status' values (in model_update) are:
+        'error' - replication in error state
+        'copying' - replication copying data to secondary (inconsistent)
+        'active' - replication copying data to secondary (consistent)
+        'active-stopped' - replication data copy on hold (consistent)
+        'inactive' - replication data copy on hold (inconsistent)
+        Values in 'replication_extended_status' and 'replication_driver_data'
+        are managed by the driver.
+
+        :param context: Context
+        :param volume: A dictionary describing the volume
+
+        """
+        msg = _("sync_replica not implemented.")
+        raise NotImplementedError(msg)
+
+    def get_replication_status(self, context, volume):
+        """Query the actual volume replication status from the driver.
+
+        Returns model_update for the volume.
+        The driver is expected to update the following entries:
+            'replication_status'
+            'replication_extended_status'
+            'replication_driver_data'
+        Possible 'replication_status' values (in model_update) are:
+        'error' - replication in error state
+        'copying' - replication copying data to secondary (inconsistent)
+        'active' - replication copying data to secondary (consistent)
+        'active-stopped' - replication data copy on hold (consistent)
+        'inactive' - replication data copy on hold (inconsistent)
+        Values in 'replication_extended_status' and 'replication_driver_data'
+        are managed by the driver.
+
+        :param context: Context
+        :param volume: A dictionary describing the volume
+        """
+        return None
+
+    def promote_replica(self, context, volume):
+        """Promote the replica to be the primary volume.
+
+        Following this command, replication between the volumes at
+        the storage level should be stopped, the replica should be
+        available to be attached, and the replication status should
+        be in status 'inactive'.
+
+        Returns model_update for the volume.
+        The driver is expected to update the following entries:
+            'replication_status'
+            'replication_extended_status'
+            'replication_driver_data'
+        Possible 'replication_status' values (in model_update) are:
+        'error' - replication in error state
+        'inactive' - replication data copy on hold (inconsistent)
+        Values in 'replication_extended_status' and 'replication_driver_data'
+        are managed by the driver.
+
+        :param context: Context
+        :param volume: A dictionary describing the volume
+        """
+        msg = _("promote_replica not implemented.")
+        raise NotImplementedError(msg)
+
+    # #######  Interface methods for DataPath (Connector) ########
+    def ensure_export(self, context, volume):
+        """Synchronously recreates an export for a volume."""
+        raise NotImplementedError()
+
+    def create_export(self, context, volume):
+        """Exports the volume.
+
+        Can optionally return a Dictionary of changes
+        to the volume object to be persisted.
+        """
+        raise NotImplementedError()
+
+    def remove_export(self, context, volume):
+        """Removes an export for a volume."""
+        raise NotImplementedError()
+
+    def initialize_connection(self, volume, connector):
+        """Allow connection to connector and return connection info."""
+        raise NotImplementedError()
+
+    def terminate_connection(self, volume, connector, **kwargs):
+        """Disallow connection from connector"""
+
+    def create_consistencygroup(self, context, group):
+        """Creates a consistencygroup."""
+        raise NotImplementedError()
+
+    def delete_consistencygroup(self, context, group):
+        """Deletes a consistency group."""
+        raise NotImplementedError()
+
+    def create_cgsnapshot(self, context, cgsnapshot):
+        """Creates a cgsnapshot."""
+        raise NotImplementedError()
+
+    def delete_cgsnapshot(self, context, cgsnapshot):
+        """Deletes a cgsnapshot."""
+        raise NotImplementedError()
+
+    def get_pool(self, volume):
+        """Return pool name where volume reside on.
+
+        :param volume: The volume hosted by the the driver.
+        :return: name of the pool where given volume is in.
+        """
+        return None
+
 
 class ISCSIDriver(VolumeDriver):
     """Executes commands relating to ISCSI volumes.
@@ -635,8 +849,8 @@ class ISCSIDriver(VolumeDriver):
         super(ISCSIDriver, self).__init__(*args, **kwargs)
 
     def _do_iscsi_discovery(self, volume):
-        #TODO(justinsb): Deprecate discovery and use stored info
-        #NOTE(justinsb): Discovery won't work with CHAP-secured targets (?)
+        # TODO(justinsb): Deprecate discovery and use stored info
+        # NOTE(justinsb): Discovery won't work with CHAP-secured targets (?)
         LOG.warn(_("ISCSI provider_location not stored, using discovery"))
 
         volume_name = volume['name']
@@ -652,7 +866,7 @@ class ISCSIDriver(VolumeDriver):
         except processutils.ProcessExecutionError as ex:
             LOG.error(_("ISCSI discovery attempt failed for:%s") %
                       volume['host'].split('@')[0])
-            LOG.debug(_("Error from iscsiadm -m discovery: %s") % ex.stderr)
+            LOG.debug("Error from iscsiadm -m discovery: %s" % ex.stderr)
             return None
 
         for target in out.splitlines():
@@ -703,7 +917,7 @@ class ISCSIDriver(VolumeDriver):
                         (volume['name']))
                 raise exception.InvalidVolume(reason=msg)
 
-            LOG.debug(_("ISCSI Discovery: Found %s") % (location))
+            LOG.debug("ISCSI Discovery: Found %s" % (location))
             properties['target_discovered'] = True
 
         results = location.split(" ")
@@ -822,18 +1036,37 @@ class ISCSIDriver(VolumeDriver):
     def _update_volume_stats(self):
         """Retrieve stats info from volume group."""
 
-        LOG.debug(_("Updating volume stats"))
+        LOG.debug("Updating volume stats")
         data = {}
         backend_name = self.configuration.safe_get('volume_backend_name')
         data["volume_backend_name"] = backend_name or 'Generic_iSCSI'
         data["vendor_name"] = 'Open Source'
         data["driver_version"] = '1.0'
         data["storage_protocol"] = 'iSCSI'
+        data["pools"] = []
 
-        data['total_capacity_gb'] = 'infinite'
-        data['free_capacity_gb'] = 'infinite'
-        data['reserved_percentage'] = 100
-        data['QoS_support'] = False
+        if self.pools:
+            for pool in self.pools:
+                new_pool = {}
+                new_pool.update(dict(
+                    pool_name=pool,
+                    total_capacity_gb=0,
+                    free_capacity_gb=0,
+                    reserved_percentage=100,
+                    QoS_support=False
+                ))
+                data["pools"].append(new_pool)
+        else:
+            # No pool configured, the whole backend will be treated as a pool
+            single_pool = {}
+            single_pool.update(dict(
+                pool_name=data["volume_backend_name"],
+                total_capacity_gb=0,
+                free_capacity_gb=0,
+                reserved_percentage=100,
+                QoS_support=False
+            ))
+            data["pools"].append(single_pool)
         self._stats = data
 
     def get_target_helper(self, db):
@@ -882,9 +1115,46 @@ class FakeISCSIDriver(ISCSIDriver):
     @staticmethod
     def fake_execute(cmd, *_args, **_kwargs):
         """Execute that simply logs the command."""
-        LOG.debug(_("FAKE ISCSI: %s"), cmd)
+        LOG.debug("FAKE ISCSI: %s", cmd)
         return (None, None)
 
+    def create_volume_from_snapshot(self, volume, snapshot):
+        """Creates a volume from a snapshot."""
+        pass
+
+    def create_cloned_volume(self, volume, src_vref):
+        """Creates a clone of the specified volume."""
+        pass
+
+    def delete_volume(self, volume):
+        """Deletes a volume."""
+        pass
+
+    def create_snapshot(self, snapshot):
+        """Creates a snapshot."""
+        pass
+
+    def delete_snapshot(self, snapshot):
+        """Deletes a snapshot."""
+        pass
+
+    def local_path(self, volume):
+        return '/tmp/volume-%s' % volume.id
+
+    def ensure_export(self, context, volume):
+        """Synchronously recreates an export for a volume."""
+        pass
+
+    def create_export(self, context, volume):
+        """Exports the volume. Can optionally return a Dictionary of changes
+        to the volume object to be persisted.
+        """
+        pass
+
+    def remove_export(self, context, volume):
+        """Removes an export for a volume."""
+        pass
+
 
 class ISERDriver(ISCSIDriver):
     """Executes commands relating to ISER volumes.
@@ -904,7 +1174,7 @@ class ISERDriver(ISCSIDriver):
     def __init__(self, *args, **kwargs):
         super(ISERDriver, self).__init__(*args, **kwargs)
         # for backward compatibility
-        self.configuration.num_iscsi_scan_tries = \
+        self.configuration.num_volume_device_scan_tries = \
             self.configuration.num_iser_scan_tries
         self.configuration.iscsi_num_targets = \
             self.configuration.iser_num_targets
@@ -912,7 +1182,7 @@ class ISERDriver(ISCSIDriver):
             self.configuration.iser_target_prefix
         self.configuration.iscsi_ip_address = \
             self.configuration.iser_ip_address
-        self.configuration.iser_port = self.configuration.iser_port
+        self.configuration.iscsi_port = self.configuration.iser_port
 
     def initialize_connection(self, volume, connector):
         """Initializes the connection and returns connection info.
@@ -943,18 +1213,37 @@ class ISERDriver(ISCSIDriver):
     def _update_volume_stats(self):
         """Retrieve stats info from volume group."""
 
-        LOG.debug(_("Updating volume stats"))
+        LOG.debug("Updating volume stats")
         data = {}
         backend_name = self.configuration.safe_get('volume_backend_name')
         data["volume_backend_name"] = backend_name or 'Generic_iSER'
         data["vendor_name"] = 'Open Source'
         data["driver_version"] = '1.0'
         data["storage_protocol"] = 'iSER'
+        data["pools"] = []
 
-        data['total_capacity_gb'] = 'infinite'
-        data['free_capacity_gb'] = 'infinite'
-        data['reserved_percentage'] = 100
-        data['QoS_support'] = False
+        if self.pools:
+            for pool in self.pools:
+                new_pool = {}
+                new_pool.update(dict(
+                    pool_name=pool,
+                    total_capacity_gb=0,
+                    free_capacity_gb=0,
+                    reserved_percentage=100,
+                    QoS_support=False
+                ))
+                data["pools"].append(new_pool)
+        else:
+            # No pool configured, the whole backend will be treated as a pool
+            single_pool = {}
+            single_pool.update(dict(
+                pool_name=data["volume_backend_name"],
+                total_capacity_gb=0,
+                free_capacity_gb=0,
+                reserved_percentage=100,
+                QoS_support=False
+            ))
+            data["pools"].append(single_pool)
         self._stats = data
 
     def get_target_helper(self, db):
@@ -982,7 +1271,7 @@ class FakeISERDriver(FakeISCSIDriver):
     @staticmethod
     def fake_execute(cmd, *_args, **_kwargs):
         """Execute that simply logs the command."""
-        LOG.debug(_("FAKE ISER: %s"), cmd)
+        LOG.debug("FAKE ISER: %s", cmd)
         return (None, None)
 
 
@@ -1024,3 +1313,21 @@ class FibreChannelDriver(VolumeDriver):
         """
         msg = _("Driver must implement initialize_connection")
         raise NotImplementedError(msg)
+
+    def validate_connector(self, connector):
+        """Fail if connector doesn't contain all the data needed by driver.
+
+        Do a check on the connector and ensure that it has wwnns, wwpns.
+        """
+        self.validate_connector_has_setting(connector, 'wwpns')
+        self.validate_connector_has_setting(connector, 'wwnns')
+
+    @staticmethod
+    def validate_connector_has_setting(connector, setting):
+        """Test for non-empty setting in connector."""
+        if setting not in connector or not connector[setting]:
+            msg = (_(
+                "FibreChannelDriver validate_connector failed. "
+                "No '%s'. Make sure HBA state is Online.") % setting)
+            LOG.error(msg)
+            raise exception.VolumeDriverException(message=msg)
