@@ -20,7 +20,6 @@ from cinder.volume import driver
 from cinder.volume.drivers.emc import emc_vmax_common
 from cinder.zonemanager import utils as fczm_utils
 
-
 LOG = logging.getLogger(__name__)
 
 
@@ -42,6 +41,7 @@ class EMCVMAXFCDriver(driver.FibreChannelDriver):
         self.common = emc_vmax_common.EMCVMAXCommon(
             'FC',
             configuration=self.configuration)
+        self.zonemanager_lookup_service = fczm_utils.create_lookup_service()
 
     def check_for_setup_error(self):
         pass
@@ -154,7 +154,7 @@ class EMCVMAXFCDriver(driver.FibreChannelDriver):
         device_number = device_info['hostlunid']
         storage_system = device_info['storagesystem']
         target_wwns, init_targ_map = self._build_initiator_target_map(
-            storage_system, connector)
+            storage_system, volume, connector)
 
         data = {'driver_volume_type': 'fibre_channel',
                 'data': {'target_lun': device_number,
@@ -162,7 +162,7 @@ class EMCVMAXFCDriver(driver.FibreChannelDriver):
                          'target_wwn': target_wwns,
                          'initiator_target_map': init_targ_map}}
 
-        LOG.debug("Return FC data: %(data)s."
+        LOG.debug("Return FC data for zone addition: %(data)s."
                   % {'data': data})
 
         return data
@@ -179,40 +179,71 @@ class EMCVMAXFCDriver(driver.FibreChannelDriver):
         :returns: data - the target_wwns and initiator_target_map if the
                          zone is to be removed, otherwise empty
         """
-        self.common.terminate_connection(volume, connector)
-
         loc = volume['provider_location']
         name = eval(loc)
         storage_system = name['keybindings']['SystemName']
+        LOG.info("Start FC detach process for volume: %(volume)s"
+                 % {'volume': volume['name']})
 
-        numVolumes = self.common.get_num_volumes_mapped(volume, connector)
-        if numVolumes > 0:
+        target_wwns, init_targ_map = self._build_initiator_target_map(
+            storage_system, volume, connector)
+
+        mvInstanceName = self.common.get_masking_view_by_volume(volume)
+        portGroupInstanceName = self.common.get_port_group_from_masking_view(
+            mvInstanceName)
+
+        LOG.info("Found port group: %(portGroup)s "
+                 "in masking view %(maskingView)s"
+                 % {'portGroup': portGroupInstanceName,
+                    'maskingView': mvInstanceName})
+
+        self.common.terminate_connection(volume, connector)
+
+        LOG.info("Looking for masking views still associated with"
+                 "Port Group %s" % portGroupInstanceName)
+        mvInstances = self.common.get_masking_views_by_port_group(
+            portGroupInstanceName)
+        if len(mvInstances) > 0:
+            LOG.debug("Found %(numViews)lu maskingviews."
+                      % {'numViews': len(mvInstances)})
             data = {'driver_volume_type': 'fibre_channel',
                     'data': {}}
-        else:
-            target_wwns, init_targ_map = self._build_initiator_target_map(
-                storage_system, connector)
+        else:  # no views found
+            LOG.debug("No Masking Views were found. Deleting zone.")
             data = {'driver_volume_type': 'fibre_channel',
                     'data': {'target_wwn': target_wwns,
                              'initiator_target_map': init_targ_map}}
 
-        LOG.debug("Return FC data: %(data)s."
+        LOG.debug("Return FC data for zone removal: %(data)s."
                   % {'data': data})
 
         return data
 
-    def _build_initiator_target_map(self, storage_system, connector):
+    def _build_initiator_target_map(self, storage_system, volume, connector):
         """Build the target_wwns and the initiator target map."""
-
-        target_wwns = self.common.get_target_wwns(storage_system, connector)
+        target_wwns = []
+        init_targ_map = {}
 
         initiator_wwns = connector['wwpns']
 
-        init_targ_map = {}
-        for initiator in initiator_wwns:
-            init_targ_map[initiator] = target_wwns
+        if self.zonemanager_lookup_service:
+            fc_targets = self.common.get_target_wwns_from_masking_view(
+                storage_system, volume, connector)
+            mapping = (
+                self.zonemanager_lookup_service.
+                get_device_mapping_from_network(initiator_wwns, fc_targets))
+            for entry in mapping:
+                map_d = mapping[entry]
+                target_wwns.extend(map_d['target_port_wwn_list'])
+                for initiator in map_d['initiator_port_wwn_list']:
+                    init_targ_map[initiator] = map_d['target_port_wwn_list']
+        else:  # no lookup service, pre-zoned case
+            target_wwns = self.common.get_target_wwns(storage_system,
+                                                      connector)
+            for initiator in initiator_wwns:
+                init_targ_map[initiator] = target_wwns
 
-        return target_wwns, init_targ_map
+        return list(set(target_wwns)), init_targ_map
 
     def extend_volume(self, volume, new_size):
         """Extend an existing volume."""
