@@ -12,18 +12,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from contextlib import nested
 import re
 import shlex
 import threading
 import time
 
-from oslo_log import log as logging
-from oslo_service import loopingcall
-from oslo_utils import excutils
-from oslo_utils import units
 import six
 
 from cinder import exception
+from cinder.i18n import _
+from cinder.openstack.common import log as logging
+from cinder.openstack.common import loopingcall
 from cinder import utils
 from cinder.volume.drivers.hitachi import hbsd_basiclib as basic_lib
 
@@ -64,7 +64,7 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
 
     def _wait_for_exec_hsnm(self, args, printflag, noretry, timeout, start):
         lock = basic_lib.get_process_lock(self.hsnm_lock_file)
-        with self.hsnm_lock, lock:
+        with nested(self.hsnm_lock, lock):
             ret, stdout, stderr = self.exec_command('env', args=args,
                                                     printflag=printflag)
 
@@ -72,7 +72,7 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
             raise loopingcall.LoopingCallDone((ret, stdout, stderr))
 
         if time.time() - start >= timeout:
-            LOG.error("snm2 command timeout.")
+            LOG.error(_("snm2 command timeout."))
             raise loopingcall.LoopingCallDone((ret, stdout, stderr))
 
         if (re.search('DMEC002047', stderr)
@@ -86,7 +86,7 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
                 or re.search('DMER0800CF', stderr)
                 or re.search('DMER0800D[0-6D]', stderr)
                 or re.search('DMES052602', stderr)):
-            LOG.error("Unexpected error occurs in snm2.")
+            LOG.error(_("Unexpected error occurs in snm2."))
             raise loopingcall.LoopingCallDone((ret, stdout, stderr))
 
     def exec_hsnm(self, command, args, printflag=True, noretry=False,
@@ -99,24 +99,9 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
 
         return loop.start(interval=interval).wait()
 
-    def _execute_with_exception(self, cmd, args, **kwargs):
-        ret, stdout, stderr = self.exec_hsnm(cmd, args, **kwargs)
-        if ret:
-            cmds = '%(cmd)s %(args)s' % {'cmd': cmd, 'args': args}
-            msg = basic_lib.output_err(
-                600, cmd=cmds, ret=ret, out=stdout, err=stderr)
-            raise exception.HBSDError(data=msg)
-
-        return ret, stdout, stderr
-
-    def _execute_and_return_stdout(self, cmd, args, **kwargs):
-        result = self._execute_with_exception(cmd, args, **kwargs)
-
-        return result[1]
-
     def get_comm_version(self):
         ret, stdout, stderr = self.exec_hsnm('auman', '-help')
-        m = re.search(r'Version (\d+).(\d+)', stdout)
+        m = re.search('Version (\d+).(\d+)', stdout)
         if not m:
             msg = basic_lib.output_err(
                 600, cmd='auman', ret=ret, out=stdout, err=stderr)
@@ -141,21 +126,12 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
                     used_list.append(int(line[2]))
                 if int(line[3]) == ldev:
                     hlu = int(line[2])
-                    LOG.warning('ldev(%(ldev)d) is already mapped '
-                                '(hlun: %(hlu)d)',
-                                {'ldev': ldev, 'hlu': hlu})
+                    LOG.warning(_('ldev(%(ldev)d) is already mapped '
+                                  '(hlun: %(hlu)d)')
+                                % {'ldev': ldev, 'hlu': hlu})
                     return hlu
         return None
 
-    def _get_lu(self, lu=None):
-        # When 'lu' is 0, it should be true. So, it cannot remove 'is None'.
-        if lu is None:
-            args = '-unit %s' % self.unit_name
-        else:
-            args = '-unit %s -lu %s' % (self.unit_name, lu)
-
-        return self._execute_and_return_stdout('auluref', args)
-
     def get_unused_ldev(self, ldev_range):
         start = ldev_range[0]
         end = ldev_range[1]
@@ -294,7 +270,7 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
             else:
                 target_wwns[port] = line[3]
 
-        LOG.debug('target wwns: %s', target_wwns)
+        LOG.debug('target wwns: %s' % target_wwns)
         return target_wwns
 
     def get_hostgroup_from_wwns(self, hostgroups, port, wwns, buf, login):
@@ -378,7 +354,7 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
         no_lun_cnt = 0
         deleted_hostgroups = []
         for hostgroup in hostgroups:
-            LOG.debug('comm_delete_lun: hostgroup is %s', hostgroup)
+            LOG.debug('comm_delete_lun: hostgroup is %s' % hostgroup)
             port = hostgroup['port']
             gid = hostgroup['gid']
             ctl_no = port[0]
@@ -422,7 +398,7 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
                 raise exception.HBSDCmdError(message=msg, ret=ret, err=stderr)
 
             deleted_hostgroups.append({'port': port, 'gid': gid})
-            LOG.debug('comm_delete_lun is over (%d)', lun)
+            LOG.debug('comm_delete_lun is over (%d)' % lun)
 
     def comm_delete_lun(self, hostgroups, ldev):
         self.comm_delete_lun_core('auhgmap', hostgroups, ldev)
@@ -553,8 +529,9 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
                 if is_once:
                     break
             else:
-                LOG.warning(basic_lib.set_msg(
-                    314, ldev=ldev, lun=hlu, port=port, id=gid))
+                msg = basic_lib.set_msg(
+                    314, ldev=ldev, lun=hlu, port=port, id=gid)
+                LOG.warning(msg)
 
         if not is_ok:
             if stderr:
@@ -609,12 +586,12 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
 
     def _wait_for_add_chap_user(self, cmd, auth_username,
                                 auth_password, start):
-        # Don't move 'import pexpect' to the beginning of the file so that
+        # Don't move 'import pexpect' to the begining of the file so that
         # a tempest can work.
         import pexpect
 
         lock = basic_lib.get_process_lock(self.hsnm_lock_file)
-        with self.hsnm_lock, lock:
+        with nested(self.hsnm_lock, lock):
             try:
                 child = pexpect.spawn(cmd)
                 child.expect('Secret: ', timeout=CHAP_TIMEOUT)
@@ -678,8 +655,8 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
                 if added_flag:
                     _ret, _stdout, _stderr = self.delete_chap_user(port)
                     if _ret:
-                        LOG.warning(basic_lib.set_msg(
-                            303, user=auth_username))
+                        msg = basic_lib.set_msg(303, user=auth_username)
+                        LOG.warning(msg)
 
                 msg = basic_lib.output_err(
                     600, cmd='auchapuser', ret=ret, out=stdout, err=stderr)
@@ -771,8 +748,8 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
                     gid = int(shlex.split(line)[0][0:3])
                     hostgroups.append(
                         {'port': port, 'gid': gid, 'detected': True})
-                    LOG.debug('Find port=%(port)s gid=%(gid)d',
-                              {'port': port, 'gid': gid})
+                    LOG.debug('Find port=%(port)s gid=%(gid)d'
+                              % {'port': port, 'gid': gid})
                 if port not in security_ports:
                     security_ports.append(port)
 
@@ -958,8 +935,8 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
 
         lines = stdout.splitlines()
         for line in lines[2:]:
-            tc_cc = re.search(r'\s(\d+\.\d) GB\s+(\d+\.\d) GB\s', line)
-            pool_tmp = re.match(r'\s*\d+', line)
+            tc_cc = re.search('\s(\d+\.\d) GB\s+(\d+\.\d) GB\s', line)
+            pool_tmp = re.match('\s*\d+', line)
             if (pool_tmp and tc_cc
                     and int(pool_tmp.group(0)) == pool_id):
                 total_gb = int(float(tc_cc.group(1)))
@@ -1047,10 +1024,10 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
 
     def trans_status_hsnm2raid(self, str):
         status = None
-        obj = re.search(r'Split\((.*)%\)', str)
+        obj = re.search('Split\((.*)%\)', str)
         if obj:
             status = basic_lib.PSUS
-        obj = re.search(r'Paired\((.*)%\)', str)
+        obj = re.search('Paired\((.*)%\)', str)
         if obj:
             status = basic_lib.PAIR
         return status
@@ -1107,48 +1084,3 @@ class HBSDSNM2(basic_lib.HBSDBasicLib):
         self.add_used_hlun('auhgmap', port, gid, list, DUMMY_LU)
 
         return list
-
-    def get_ldev_size_in_gigabyte(self, ldev, existing_ref):
-        param = 'unit_name'
-        if param not in existing_ref:
-            msg = basic_lib.output_err(700, param=param)
-            raise exception.HBSDError(data=msg)
-        storage = existing_ref.get(param)
-        if storage != self.conf.hitachi_unit_name:
-            msg = basic_lib.output_err(648, resource=param)
-            raise exception.HBSDError(data=msg)
-
-        try:
-            stdout = self._get_lu(ldev)
-        except exception.HBSDError:
-            with excutils.save_and_reraise_exception():
-                basic_lib.output_err(648, resource='LDEV')
-
-        lines = stdout.splitlines()
-        line = lines[2]
-
-        splits = shlex.split(line)
-
-        vol_type = splits[len(splits) - 1]
-        if basic_lib.NORMAL_VOLUME_TYPE != vol_type:
-            msg = basic_lib.output_err(702, ldev=ldev)
-            raise exception.HBSDError(data=msg)
-
-        dppool = splits[5]
-        if 'N/A' == dppool:
-            msg = basic_lib.output_err(702, ldev=ldev)
-            raise exception.HBSDError(data=msg)
-
-        # Hitachi storage calculates volume sizes in a block unit, 512 bytes.
-        # So, units.Gi is divided by 512.
-        size = int(splits[1])
-        if size % (units.Gi / 512):
-            msg = basic_lib.output_err(703, ldev=ldev)
-            raise exception.HBSDError(data=msg)
-
-        num_port = int(splits[len(splits) - 2])
-        if num_port:
-            msg = basic_lib.output_err(704, ldev=ldev)
-            raise exception.HBSDError(data=msg)
-
-        return size / (units.Gi / 512)
