@@ -37,6 +37,7 @@ from cinder import utils
 from cinder.volume.drivers.netapp.api import NaApiError
 from cinder.volume.drivers.netapp.api import NaElement
 from cinder.volume.drivers.netapp.api import NaServer
+from cinder.volume.drivers.netapp.options import netapp_7mode_opts
 from cinder.volume.drivers.netapp.options import netapp_basicauth_opts
 from cinder.volume.drivers.netapp.options import netapp_cluster_opts
 from cinder.volume.drivers.netapp.options import netapp_connection_opts
@@ -59,6 +60,7 @@ class NetAppNFSDriver(nfs.NfsDriver):
       Executes commands relating to Volumes.
     """
 
+    # do not increment this as it may be used in volume type definitions
     VERSION = "1.0.0"
 
     def __init__(self, *args, **kwargs):
@@ -66,6 +68,7 @@ class NetAppNFSDriver(nfs.NfsDriver):
         validate_instantiation(**kwargs)
         self._execute = None
         self._context = None
+        self._app_version = kwargs.pop("app_version", "unknown")
         super(NetAppNFSDriver, self).__init__(*args, **kwargs)
         self.configuration.append_config_values(netapp_connection_opts)
         self.configuration.append_config_values(netapp_basicauth_opts)
@@ -670,9 +673,7 @@ class NetAppDirectNfsDriver (NetAppNFSDriver):
         """Raises error if any required configuration flag is missing."""
         required_flags = ['netapp_login',
                           'netapp_password',
-                          'netapp_server_hostname',
-                          'netapp_server_port',
-                          'netapp_transport_type']
+                          'netapp_server_hostname']
         for flag in required_flags:
             if not getattr(self.configuration, flag, None):
                 raise exception.CinderException(_('%s is not set') % flag)
@@ -686,6 +687,8 @@ class NetAppDirectNfsDriver (NetAppNFSDriver):
             style=NaServer.STYLE_LOGIN_PASSWORD,
             username=self.configuration.netapp_login,
             password=self.configuration.netapp_password)
+        if self.configuration.netapp_server_port is not None:
+            client.set_port(self.configuration.netapp_server_port)
         return client
 
     def _do_custom_setup(self, client):
@@ -961,7 +964,8 @@ class NetAppDirectCmodeNfsDriver (NetAppDirectNfsDriver):
         data['pools'] = self._get_pool_stats()
 
         self._spawn_clean_cache_job()
-        na_utils.provide_ems(self, self._client, data, netapp_backend)
+        na_utils.provide_ems(self, self._client, netapp_backend,
+                             self._app_version)
         self._stats = data
 
     def _get_pool_stats(self):
@@ -1328,11 +1332,13 @@ class NetAppDirect7modeNfsDriver (NetAppDirectNfsDriver):
 
     def __init__(self, *args, **kwargs):
         super(NetAppDirect7modeNfsDriver, self).__init__(*args, **kwargs)
+        self.configuration.append_config_values(netapp_7mode_opts)
 
     def _do_custom_setup(self, client):
         """Do the customized set up on client if any for 7 mode."""
         (major, minor) = self._get_ontapi_version()
         client.set_api_version(major, minor)
+        self.vfiler = self.configuration.netapp_vfiler
 
     def check_for_setup_error(self):
         """Checks if setup occurred properly."""
@@ -1419,7 +1425,7 @@ class NetAppDirect7modeNfsDriver (NetAppDirectNfsDriver):
         """Gets the actual path on the filer for export path."""
         storage_path = NaElement.create_node_with_children(
             'nfs-exportfs-storage-path', **{'pathname': export_path})
-        result = self._invoke_successfully(storage_path, None)
+        result = self._invoke_successfully(storage_path, self.vfiler)
         if result.get_child_content('actual-pathname'):
             return result.get_child_content('actual-pathname')
         raise exception.NotFound(_('No storage path found for export path %s')
@@ -1439,7 +1445,7 @@ class NetAppDirect7modeNfsDriver (NetAppDirectNfsDriver):
             **{'source-path': src_path,
                 'destination-path': dest_path,
                 'no-snap': 'true'})
-        result = self._invoke_successfully(clone_start, None)
+        result = self._invoke_successfully(clone_start, self.vfiler)
         clone_id_el = result.get_child_by_name('clone-id')
         cl_id_info = clone_id_el.get_child_by_name('clone-id-info')
         vol_uuid = cl_id_info.get_child_content('volume-uuid')
@@ -1454,26 +1460,31 @@ class NetAppDirect7modeNfsDriver (NetAppDirectNfsDriver):
         clone_id.add_node_with_children('clone-id-info',
                                         **{'clone-op-id': clone_op_id,
                                             'volume-uuid': vol_uuid})
-        task_running = True
-        while task_running:
-            result = self._invoke_successfully(clone_ls_st, None)
-            status = result.get_child_by_name('status')
-            ops_info = status.get_children()
-            if ops_info:
-                state = ops_info[0].get_child_content('clone-state')
-                if state == 'completed':
-                    task_running = False
-                elif state == 'failed':
-                    code = ops_info[0].get_child_content('error')
-                    reason = ops_info[0].get_child_content('reason')
-                    raise NaApiError(code, reason)
-                else:
-                    time.sleep(1)
+        clone_running = True
+        while clone_running:
+            result = self._invoke_successfully(clone_ls_st, self.vfiler)
+            clone_running = self._is_clone_still_running(result, clone_id)
+
+    def _is_clone_still_running(self, result, clone_id):
+        clone_running = True
+        status = result.get_child_by_name('status')
+        ops_info = status.get_children()
+        if ops_info:
+            state = ops_info[0].get_child_content('clone-state')
+            if state == 'completed':
+                clone_running = False
+            elif state == 'failed':
+                code = ops_info[0].get_child_content('error')
+                reason = ops_info[0].get_child_content('reason')
+                raise NaApiError(code, reason)
             else:
-                raise NaApiError(
-                    'UnknownCloneId',
-                    'No clone operation for clone id %s found on the filer'
-                    % (clone_id))
+                time.sleep(1)
+        else:
+            raise NaApiError(
+                'UnknownCloneId',
+                'No clone operation for clone id %s found on the filer'
+                % clone_id)
+        return clone_running
 
     def _clear_clone(self, clone_id):
         """Clear the clone information.
@@ -1487,7 +1498,7 @@ class NetAppDirect7modeNfsDriver (NetAppDirectNfsDriver):
         retry = 3
         while retry:
             try:
-                self._invoke_successfully(clone_clear, None)
+                self._invoke_successfully(clone_clear, self.vfiler)
                 break
             except Exception:
                 # Filer might be rebooting
@@ -1510,8 +1521,8 @@ class NetAppDirect7modeNfsDriver (NetAppDirectNfsDriver):
         data['pools'] = self._get_pool_stats()
 
         self._spawn_clean_cache_job()
-        na_utils.provide_ems(self, self._client, data, netapp_backend,
-                             server_type="7mode")
+        na_utils.provide_ems(self, self._client, netapp_backend,
+                             self._app_version, server_type="7mode")
         self._stats = data
 
     def _get_pool_stats(self):
