@@ -23,12 +23,16 @@ NetApp drivers to achieve the desired functionality.
 import base64
 import binascii
 import copy
+import decimal
 import platform
 import socket
 import uuid
 
+import six
+
 from cinder import context
 from cinder import exception
+from cinder.i18n import _
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import processutils as putils
 from cinder.openstack.common import timeutils
@@ -44,6 +48,14 @@ from cinder.volume import volume_types
 LOG = logging.getLogger(__name__)
 
 
+OBSOLETE_SSC_SPECS = {'netapp:raid_type': 'netapp_raid_type',
+                      'netapp:disk_type': 'netapp_disk_type'}
+DEPRECATED_SSC_SPECS = {'netapp_unmirrored': 'netapp_mirrored',
+                        'netapp_nodedup': 'netapp_dedup',
+                        'netapp_nocompression': 'netapp_compression',
+                        'netapp_thick_provisioned': 'netapp_thin_provisioned'}
+
+
 def provide_ems(requester, server, netapp_backend, app_version,
                 server_type="cluster"):
     """Provide ems with volume stats for the requester.
@@ -126,7 +138,7 @@ def provide_ems(requester, server, netapp_backend, app_version,
             else:
                 na_server.set_vfiler(None)
             na_server.invoke_successfully(ems, True)
-            LOG.debug(_("ems executed successfully."))
+            LOG.debug("ems executed successfully.")
         except NaApiError as e:
             LOG.warn(_("Failed to invoke ems. Message : %s") % e)
         finally:
@@ -197,32 +209,32 @@ def invoke_api(na_server, api_name, api_family='cm', query=None,
 def create_api_request(api_name, query=None, des_result=None,
                        additional_elems=None, is_iter=False,
                        record_step=50, tag=None):
-        """Creates a NetApp api request.
+    """Creates a NetApp api request.
 
-            :param api_name: api name string
-            :param query: api query as dict
-            :param des_result: desired result as dict
-            :param additional_elems: dict other than query and des_result
-            :param is_iter: is iterator api
-            :param record_step: records at a time for iter api
-            :param tag: next tag for iter api
-        """
-        api_el = NaElement(api_name)
-        if query:
-            query_el = NaElement('query')
-            query_el.translate_struct(query)
-            api_el.add_child_elem(query_el)
-        if des_result:
-            res_el = NaElement('desired-attributes')
-            res_el.translate_struct(des_result)
-            api_el.add_child_elem(res_el)
-        if additional_elems:
-            api_el.translate_struct(additional_elems)
-        if is_iter:
-            api_el.add_new_child('max-records', str(record_step))
-        if tag:
-            api_el.add_new_child('tag', tag, True)
-        return api_el
+        :param api_name: api name string
+        :param query: api query as dict
+        :param des_result: desired result as dict
+        :param additional_elems: dict other than query and des_result
+        :param is_iter: is iterator api
+        :param record_step: records at a time for iter api
+        :param tag: next tag for iter api
+    """
+    api_el = NaElement(api_name)
+    if query:
+        query_el = NaElement('query')
+        query_el.translate_struct(query)
+        api_el.add_child_elem(query_el)
+    if des_result:
+        res_el = NaElement('desired-attributes')
+        res_el.translate_struct(des_result)
+        api_el.add_child_elem(res_el)
+    if additional_elems:
+        api_el.translate_struct(additional_elems)
+    if is_iter:
+        api_el.add_new_child('max-records', str(record_step))
+    if tag:
+        api_el.add_new_child('tag', tag, True)
+    return api_el
 
 
 def to_bool(val):
@@ -232,7 +244,7 @@ def to_bool(val):
         if (strg == 'true' or strg == 'y'
             or strg == 'yes' or strg == 'enabled'
                 or strg == '1'):
-                    return True
+            return True
         else:
             return False
     else:
@@ -270,12 +282,13 @@ def get_volume_extra_specs(volume):
     return specs
 
 
-def check_apis_on_cluster(na_server, api_list=[]):
+def check_apis_on_cluster(na_server, api_list=None):
     """Checks api availability and permissions on cluster.
 
     Checks api availability and permissions for executing user.
     Returns a list of failed apis.
     """
+    api_list = api_list or []
     failed_apis = []
     if api_list:
         api_version = na_server.get_api_version()
@@ -360,6 +373,43 @@ def convert_es_fmt_to_uuid(es_label):
     return uuid.UUID(binascii.hexlify(base64.b32decode(es_label_b32)))
 
 
+def round_down(value, precision):
+    return float(decimal.Decimal(six.text_type(value)).quantize(
+        decimal.Decimal(precision), rounding=decimal.ROUND_DOWN))
+
+
+def log_extra_spec_warnings(extra_specs):
+    for spec in (set(extra_specs.keys() if extra_specs else []) &
+                 set(OBSOLETE_SSC_SPECS.keys())):
+            msg = _('Extra spec %(old)s is obsolete.  Use %(new)s instead.')
+            args = {'old': spec, 'new': OBSOLETE_SSC_SPECS[spec]}
+            LOG.warn(msg % args)
+    for spec in (set(extra_specs.keys() if extra_specs else []) &
+                 set(DEPRECATED_SSC_SPECS.keys())):
+            msg = _('Extra spec %(old)s is deprecated.  Use %(new)s instead.')
+            args = {'old': spec, 'new': DEPRECATED_SSC_SPECS[spec]}
+            LOG.warn(msg % args)
+
+
+def get_iscsi_connection_properties(address, port, iqn, lun_id, volume):
+        properties = {}
+        properties['target_discovered'] = False
+        properties['target_portal'] = '%s:%s' % (address, port)
+        properties['target_iqn'] = iqn
+        properties['target_lun'] = int(lun_id)
+        properties['volume_id'] = volume['id']
+        auth = volume['provider_auth']
+        if auth:
+            (auth_method, auth_username, auth_secret) = auth.split()
+            properties['auth_method'] = auth_method
+            properties['auth_username'] = auth_username
+            properties['auth_password'] = auth_secret
+        return {
+            'driver_volume_type': 'iscsi',
+            'data': properties,
+        }
+
+
 class OpenStackInfo(object):
     """OS/distribution, release, and version.
 
@@ -418,7 +468,7 @@ class OpenStackInfo(object):
     def _update_info_from_rpm(self):
         LOG.debug('Trying rpm command.')
         try:
-            out, err = putils.execute("rpm", "-qa", "--queryformat",
+            out, err = putils.execute("rpm", "-q", "--queryformat",
                                       "'%{version}\t%{release}\t%{vendor}'",
                                       self.PACKAGE_NAME)
             if not out:
