@@ -14,16 +14,16 @@
 #    under the License.
 
 
-from oslo_config import cfg
+from oslo.config import cfg
 
 
 DPL_OPTS = [
     cfg.StrOpt('dpl_pool',
                default='',
                help='DPL pool uuid in which DPL volumes are stored.'),
-    cfg.PortOpt('dpl_port',
-                default=8357,
-                help='DPL port number.'),
+    cfg.IntOpt('dpl_port',
+               default=8357,
+               help='DPL port number.'),
 ]
 
 CONF = cfg.CONF
