@@ -25,10 +25,11 @@ import tempfile
 from oslo.config import cfg
 
 from cinder import exception
+from cinder.i18n import _
 from cinder.image import image_utils
 from cinder.openstack.common import log as logging
 from cinder.openstack.common import processutils
-from cinder import units
+from cinder.openstack.common import units
 from cinder.volume import driver
 
 
@@ -90,7 +91,7 @@ class SheepdogDriver(driver.VolumeDriver):
 
     def _resize(self, volume, size=None):
         if not size:
-            size = int(volume['size']) * units.GiB
+            size = int(volume['size']) * units.Gi
 
         self._try_execute('collie', 'vdi', 'resize',
                           volume['name'], size)
@@ -172,8 +173,8 @@ class SheepdogDriver(driver.VolumeDriver):
             m = self.stats_pattern.match(stdout)
             total = float(m.group(1))
             used = float(m.group(2))
-            stats['total_capacity_gb'] = total / units.GiB
-            stats['free_capacity_gb'] = (total - used) / units.GiB
+            stats['total_capacity_gb'] = total / units.Gi
+            stats['free_capacity_gb'] = (total - used) / units.Gi
         except processutils.ProcessExecutionError:
             LOG.exception(_('error refreshing volume stats'))
 
@@ -189,7 +190,7 @@ class SheepdogDriver(driver.VolumeDriver):
         old_size = volume['size']
 
         try:
-            size = int(new_size) * units.GiB
+            size = int(new_size) * units.Gi
             self._resize(volume, size=size)
         except Exception:
             msg = _('Failed to Extend Volume '
@@ -197,7 +198,7 @@ class SheepdogDriver(driver.VolumeDriver):
             LOG.error(msg)
             raise exception.VolumeBackendAPIException(data=msg)
 
-        LOG.debug(_("Extend volume from %(old_size)s GB to %(new_size)s GB."),
+        LOG.debug("Extend volume from %(old_size)s GB to %(new_size)s GB.",
                   {'old_size': old_size, 'new_size': new_size})
 
     def backup_volume(self, context, backup, backup_service):
