@@ -1,4 +1,4 @@
-# Copyright (c) 2014, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2014, Oracle and/or its affiliates. All rights reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -15,15 +15,14 @@
 ZFS Storage Appliance REST API Client Programmatic Interface
 """
 
+import httplib
 import json
-import ssl
+import StringIO
 import time
+import urllib2
 
-from oslo_log import log
-from oslo_utils import strutils
-import six
-from six.moves import http_client
-from six.moves import urllib
+from cinder.i18n import _
+from cinder.openstack.common import log
 
 LOG = log.getLogger(__name__)
 
@@ -35,47 +34,46 @@ class Status(object):
         pass
 
     #: Request return OK
-    OK = http_client.OK
+    OK = httplib.OK
 
     #: New resource created successfully
-    CREATED = http_client.CREATED
+    CREATED = httplib.CREATED
 
     #: Command accepted
-    ACCEPTED = http_client.ACCEPTED
+    ACCEPTED = httplib.ACCEPTED
 
     #: Command returned OK but no data will be returned
-    NO_CONTENT = http_client.NO_CONTENT
+    NO_CONTENT = httplib.NO_CONTENT
 
     #: Bad Request
-    BAD_REQUEST = http_client.BAD_REQUEST
+    BAD_REQUEST = httplib.BAD_REQUEST
 
     #: User is not authorized
-    UNAUTHORIZED = http_client.UNAUTHORIZED
+    UNAUTHORIZED = httplib.UNAUTHORIZED
 
     #: The request is not allowed
-    FORBIDDEN = http_client.FORBIDDEN
+    FORBIDDEN = httplib.FORBIDDEN
 
     #: The requested resource was not found
-    NOT_FOUND = http_client.NOT_FOUND
+    NOT_FOUND = httplib.NOT_FOUND
 
     #: The request is not allowed
-    NOT_ALLOWED = http_client.METHOD_NOT_ALLOWED
+    NOT_ALLOWED = httplib.METHOD_NOT_ALLOWED
 
     #: Request timed out
-    TIMEOUT = http_client.REQUEST_TIMEOUT
+    TIMEOUT = httplib.REQUEST_TIMEOUT
 
     #: Invalid request
-    CONFLICT = http_client.CONFLICT
+    CONFLICT = httplib.CONFLICT
 
     #: Service Unavailable
-    BUSY = http_client.SERVICE_UNAVAILABLE
+    BUSY = httplib.SERVICE_UNAVAILABLE
 
 
 class RestResult(object):
     """Result from a REST API operation"""
     def __init__(self, response=None, err=None):
-        """Initialize a RestResult containing the results from a REST call.
-
+        """Initialize a RestResult containing the results from a REST call
         :param response: HTTP response
         """
         self.response = response
@@ -86,15 +84,15 @@ class RestResult(object):
             self.status = self.response.getcode()
             result = self.response.read()
             while result:
-                self.data += result.decode("utf-8")
+                self.data += result
                 result = self.response.read()
 
         if self.error:
             self.status = self.error.code
-            self.data = http_client.responses[self.status]
+            self.data = httplib.responses[self.status]
 
-        LOG.debug('Response code: %s', self.status)
-        LOG.debug('Response data: %s', self.data)
+        LOG.debug('Response code: %s' % self.status)
+        LOG.debug('Response data: %s' % self.data)
 
     def get_header(self, name):
         """Get an HTTP header with the given name from the results
@@ -105,7 +103,7 @@ class RestResult(object):
         if self.response is None:
             return None
         info = self.response.info()
-        return info.get(name)
+        return info.getheader(name)
 
 
 class RestClientError(Exception):
@@ -122,15 +120,15 @@ class RestClientError(Exception):
         self.code = status
         self.name = name
         self.msg = message
-        if status in http_client.responses:
-            self.msg = http_client.responses[status]
+        if status in httplib.responses:
+            self.msg = httplib.responses[status]
 
     def __str__(self):
         return "%d %s %s" % (self.code, self.name, self.msg)
 
 
 class RestClientURL(object):
-    """ZFSSA urllib client"""
+    """ZFSSA urllib2 client"""
     def __init__(self, url, **kwargs):
         """Initialize a REST client.
 
@@ -174,21 +172,21 @@ class RestClientURL(object):
         try:
             result = self.post("/access/v1")
             del self.headers['authorization']
-            if result.status == http_client.CREATED:
+            if result.status == httplib.CREATED:
                 self.headers['x-auth-session'] = \
                     result.get_header('x-auth-session')
                 self.do_logout = True
-                LOG.info('ZFSSA version: %s',
+                LOG.info(_('ZFSSA version: %s') %
                          result.get_header('x-zfssa-version'))
 
-            elif result.status == http_client.NOT_FOUND:
+            elif result.status == httplib.NOT_FOUND:
                 raise RestClientError(result.status, name="ERR_RESTError",
                                       message="REST Not Available: \
                                       Please Upgrade")
 
-        except RestClientError:
+        except RestClientError as err:
             del self.headers['authorization']
-            raise
+            raise err
 
     def login(self, auth_str):
         """Login to an appliance using a user name and password.
@@ -227,7 +225,7 @@ class RestClientURL(object):
         :cmd_params args: The path part
         :cmd_params kwargs: The query part
         """
-        buf = six.StringIO()
+        buf = StringIO.StringIO()
         query = "?"
         for arg in args:
             buf.write("/")
@@ -244,7 +242,7 @@ class RestClientURL(object):
     def request(self, path, request, body=None, **kwargs):
         """Make an HTTP request and return the results
 
-        :param path: Path used with the initialized URL to make a request
+        :param path: Path used with the initiazed URL to make a request
         :param request: HTTP request type (GET, POST, PUT, DELETE)
         :param body: HTTP body of request
         :key accept: Set HTTP 'Accept' header with this value
@@ -257,64 +255,47 @@ class RestClientURL(object):
 
         if body:
             if isinstance(body, dict):
-                body = json.dumps(body)
-            body = body.encode("utf-8")
+                body = str(json.dumps(body))
+
+        if body and len(body):
             out_hdrs['content-length'] = len(body)
-        else:
-            body = None
 
         zfssaurl = self._path(path, kwargs.get("base_path"))
-        req = urllib.request.Request(zfssaurl, body, out_hdrs)
+        req = urllib2.Request(zfssaurl, body, out_hdrs)
         req.get_method = lambda: request
         maxreqretries = kwargs.get("maxreqretries", 10)
         retry = 0
         response = None
 
-        LOG.debug('Request: %(request)s %(url)s',
-                  {'request': request, 'url': zfssaurl})
-        LOG.debug('Out headers: %s', out_hdrs)
+        LOG.debug('Request: %s %s' % (request, zfssaurl))
+        LOG.debug('Out headers: %s' % out_hdrs)
         if body and body != '':
-            # body may contain chap secret so must be masked
-            LOG.debug('Body: %s', strutils.mask_password(body))
-
-        context = None
-        if hasattr(ssl, '_create_unverified_context'):
-            context = ssl._create_unverified_context()
-        else:
-            context = None
+            LOG.debug('Body: %s' % body)
 
         while retry < maxreqretries:
             try:
-                if context:
-                    # only schemes that can be used will be http or https if it
-                    # is given in the path variable, or the path will begin
-                    # with the REST API location meaning invalid or unwanted
-                    # schemes cannot be used
-                    response = urllib.request.urlopen(req,  # nosec
-                                                      timeout=self.timeout,
-                                                      context=context)
+                response = urllib2.urlopen(req, timeout=self.timeout)
+            except urllib2.HTTPError as err:
+                if err.code == httplib.NOT_FOUND:
+                    LOG.debug('REST Not Found: %s' % err.code)
                 else:
-                    response = urllib.request.urlopen(req,  # nosec : see above
-                                                      timeout=self.timeout)
-            except urllib.error.HTTPError as err:
-                if err.code == http_client.NOT_FOUND:
-                    LOG.debug('REST Not Found: %s', err.code)
-                else:
-                    LOG.error('REST Not Available: %s', err.code)
+                    LOG.error(_('REST Not Available: %s') % err.code)
 
-                if err.code == http_client.SERVICE_UNAVAILABLE and \
+                if err.code == httplib.SERVICE_UNAVAILABLE and \
                    retry < maxreqretries:
                     retry += 1
                     time.sleep(1)
-                    LOG.error('Server Busy retry request: %s', retry)
+                    LOG.error(_('Server Busy retry request: %s') % retry)
                     continue
-                if (err.code == http_client.UNAUTHORIZED or
-                    err.code == http_client.INTERNAL_SERVER_ERROR) and \
+                if (err.code == httplib.UNAUTHORIZED or
+                    err.code == httplib.INTERNAL_SERVER_ERROR) and \
                    '/access/v1' not in zfssaurl:
                     try:
-                        LOG.error('Authorizing request: %(zfssaurl)s '
-                                  'retry: %(retry)d.',
-                                  {'zfssaurl': zfssaurl, 'retry': retry})
+                        LOG.error(_('Authorizing request: '
+                                    '%(zfssaurl)s'
+                                    'retry: %(retry)d .')
+                                  % {'zfssaurl': zfssaurl,
+                                     'retry': retry})
                         self._authorize()
                         req.add_header('x-auth-session',
                                        self.headers['x-auth-session'])
@@ -326,16 +307,15 @@ class RestClientURL(object):
 
                 return RestResult(err=err)
 
-            except urllib.error.URLError as err:
-                LOG.error('URLError: %s', err.reason)
+            except urllib2.URLError as err:
+                LOG.error(_('URLError: %s') % err.reason)
                 raise RestClientError(-1, name="ERR_URLError",
                                       message=err.reason)
 
             break
 
-        if (response and
-            (response.getcode() == http_client.SERVICE_UNAVAILABLE and
-                retry >= maxreqretries)):
+        if response and response.getcode() == httplib.SERVICE_UNAVAILABLE and \
+           retry >= maxreqretries:
             raise RestClientError(response.getcode(), name="ERR_HTTPError",
                                   message="REST Not Available: Disabled")
 
