@@ -26,28 +26,22 @@ add_connection and delete_connection interfaces.
 :zone_activate: Used by: class: 'FCZoneDriver'. Defaults to True
 :zone_name_prefix: Used by: class: 'FCZoneDriver'. Defaults to 'openstack'
 """
-import re
-import string
 
-from oslo_concurrency import lockutils
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_utils import excutils
-from oslo_utils import importutils
+from oslo.config import cfg
+import six
 
 from cinder import exception
 from cinder.i18n import _
-from cinder import interface
+from cinder.openstack.common import excutils
+from cinder.openstack.common import importutils
+from cinder.openstack.common import lockutils
+from cinder.openstack.common import log as logging
 from cinder.zonemanager.drivers.cisco import cisco_fabric_opts as fabric_opts
-from cinder.zonemanager.drivers.cisco import exception as c_exception
-from cinder.zonemanager.drivers.cisco import fc_zone_constants as ZoneConstant
-from cinder.zonemanager.drivers import driver_utils
-from cinder.zonemanager.drivers import fc_zone_driver
-from cinder.zonemanager import utils as zm_utils
+from cinder.zonemanager.drivers.fc_zone_driver import FCZoneDriver
+from cinder.zonemanager.utils import get_formatted_wwn
 
 LOG = logging.getLogger(__name__)
 
-SUPPORTED_CHARS = string.ascii_letters + string.digits + '$' + '-' + '^' + '_'
 cisco_opts = [
     cfg.StrOpt('cisco_sb_connector',
                default='cinder.zonemanager.drivers.cisco'
@@ -56,27 +50,20 @@ cisco_opts = [
 ]
 
 CONF = cfg.CONF
-CONF.register_opts(cisco_opts, group='fc-zone-manager')
+CONF.register_opts(cisco_opts, 'fc-zone-manager')
 
 
-@interface.fczmdriver
-class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
+class CiscoFCZoneDriver(FCZoneDriver):
     """Cisco FC zone driver implementation.
 
     OpenStack Fibre Channel zone driver to manage FC zoning in
     Cisco SAN fabrics.
 
-    .. code-block:: none
-
-      Version history:
+    Version history:
         1.0 - Initial Cisco FC zone driver
-        1.1 - Added friendly zone name support
     """
 
-    VERSION = "1.1.0"
-
-    # ThirdPartySystems wiki name
-    CI_WIKI_NAME = "Cisco_ZM_CI"
+    VERSION = "1.0.0"
 
     def __init__(self, **kwargs):
         super(CiscoFCZoneDriver, self).__init__(**kwargs)
@@ -92,7 +79,7 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
             base_san_opts = []
             if not fabric_names:
                 base_san_opts.append(
-                    cfg.StrOpt('fc_fabric_names',
+                    cfg.StrOpt('fc_fabric_names', default=None,
                                help='Comma separated list of fibre channel '
                                'fabric names. This list of names is used to'
                                ' retrieve other SAN credentials for connecting'
@@ -121,13 +108,8 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                 self.fabric_configs = fabric_opts.load_fabric_configurations(
                     fabric_names)
 
-    @staticmethod
-    def get_driver_options():
-        return cisco_opts
-
     @lockutils.synchronized('cisco', 'fcfabric-', True)
-    def add_connection(self, fabric, initiator_target_map, host_name=None,
-                       storage_system=None):
+    def add_connection(self, fabric, initiator_target_map):
         """Concrete implementation of add_connection.
 
         Based on zoning policy and state of each I-T pair, list of zone
@@ -140,9 +122,9 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
         :param initiator_target_map: Mapping of initiator to list of targets
         """
 
-        LOG.debug("Add connection for Fabric: %s", fabric)
-        LOG.info("CiscoFCZoneDriver - Add connection "
-                 "for I-T map: %s", initiator_target_map)
+        LOG.debug("Add connection for Fabric:%s", fabric)
+        LOG.info(_("CiscoFCZoneDriver - Add connection "
+                   "for I-T map: %s"), initiator_target_map)
         fabric_ip = self.fabric_configs[fabric].safe_get(
             'cisco_fc_fabric_address')
         fabric_user = self.fabric_configs[fabric].safe_get(
@@ -156,15 +138,10 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
             'cisco_zoning_policy')
         if zoning_policy_fab:
             zoning_policy = zoning_policy_fab
-        zone_name_prefix = self.fabric_configs[fabric].safe_get(
-            'cisco_zone_name_prefix')
-
-        if not zone_name_prefix:
-            zone_name_prefix = self.configuration.cisco_zone_name_prefix
 
         zoning_vsan = self.fabric_configs[fabric].safe_get('cisco_zoning_vsan')
 
-        LOG.info("Zoning policy for Fabric %s", zoning_policy)
+        LOG.info(_("Zoning policy for Fabric %s"), zoning_policy)
 
         statusmap_from_fabric = self.get_zoning_status(
             fabric_ip, fabric_user, fabric_pwd, fabric_port, zoning_vsan)
@@ -176,115 +153,80 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
             zone_names = []
             if cfgmap_from_fabric.get('zones'):
                 zone_names = cfgmap_from_fabric['zones'].keys()
-            # based on zoning policy, create zone member list and
-            # push changes to fabric.
-            for initiator_key in initiator_target_map.keys():
-                zone_map = {}
-                zone_update_map = {}
-                initiator = initiator_key.lower()
-                t_list = initiator_target_map[initiator_key]
-                if zoning_policy == 'initiator-target':
-                    for t in t_list:
-                        target = t.lower()
-                        zone_members = [
-                            zm_utils.get_formatted_wwn(initiator),
-                            zm_utils.get_formatted_wwn(target)]
-                        zone_name = (
-                            driver_utils.get_friendly_zone_name(
-                                zoning_policy,
-                                initiator,
-                                target,
-                                host_name,
-                                storage_system,
-                                zone_name_prefix,
-                                SUPPORTED_CHARS))
-                        if (len(cfgmap_from_fabric) == 0 or (
-                                zone_name not in zone_names)):
-                            zone_map[zone_name] = zone_members
-                        else:
-                            # This is I-T zoning, skip if zone exists.
-                            LOG.info("Zone exists in I-T mode. "
-                                     "Skipping zone creation %s",
-                                     zone_name)
-                elif zoning_policy == 'initiator':
-                    zone_members = [
-                        zm_utils.get_formatted_wwn(initiator)]
-                    for t in t_list:
-                        target = t.lower()
-                        zone_members.append(
-                            zm_utils.get_formatted_wwn(target))
-                    zone_name = (
-                        driver_utils.get_friendly_zone_name(
-                            zoning_policy,
-                            initiator,
-                            target,
-                            host_name,
-                            storage_system,
-                            zone_name_prefix,
-                            SUPPORTED_CHARS))
+                # based on zoning policy, create zone member list and
+                # push changes to fabric.
+                for initiator_key in initiator_target_map.keys():
+                    zone_map = {}
+                    initiator = initiator_key.lower()
+                    t_list = initiator_target_map[initiator_key]
+                    if zoning_policy == 'initiator-target':
+                        for t in t_list:
+                            target = t.lower()
+                            zone_members = [get_formatted_wwn(initiator),
+                                            get_formatted_wwn(target)]
+                            zone_name = (self.
+                                         configuration.cisco_zone_name_prefix
+                                         + initiator.replace(':', '')
+                                         + target.replace(':', ''))
+                            if (len(cfgmap_from_fabric) == 0 or (
+                                    zone_name not in zone_names)):
+                                zone_map[zone_name] = zone_members
+                            else:
+                                # This is I-T zoning, skip if zone exists.
+                                LOG.info(_("Zone exists in I-T mode. "
+                                           "Skipping zone creation %s"),
+                                         zone_name)
+                    elif zoning_policy == 'initiator':
+                        zone_members = [get_formatted_wwn(initiator)]
+                        for t in t_list:
+                            target = t.lower()
+                            zone_members.append(get_formatted_wwn(target))
 
-                    # If zone exists, then perform an update_zone and add
-                    # new members into existing zone.
-                    if zone_name and (zone_name in zone_names):
-                        zone_members = list(filter(
-                            lambda x: x not in
-                            cfgmap_from_fabric['zones'][zone_name],
-                            zone_members))
-                        if zone_members:
-                            zone_update_map[zone_name] = zone_members
-                    else:
+                        zone_name = self.configuration.cisco_zone_name_prefix \
+                            + initiator.replace(':', '')
+
+                        if len(zone_names) > 0 and (zone_name in zone_names):
+                            zone_members = zone_members + filter(
+                                lambda x: x not in zone_members,
+                                cfgmap_from_fabric['zones'][zone_name])
                         zone_map[zone_name] = zone_members
-                else:
-                    msg = _("Zoning Policy: %s, not"
-                            " recognized") % zoning_policy
-                    LOG.error(msg)
-                    raise exception.FCZoneDriverException(msg)
+                    else:
+                        msg = _("Zoning Policy: %s, not"
+                                " recognized") % zoning_policy
+                        LOG.error(msg)
+                        raise exception.FCZoneDriverException(msg)
 
-            LOG.info("Zone map to add: %(zone_map)s",
-                     {'zone_map': zone_map})
-            LOG.info("Zone map to update add: %(zone_update_map)s",
-                     {'zone_update_map': zone_update_map})
-            if zone_map or zone_update_map:
-                conn = None
-                try:
-                    conn = importutils.import_object(
-                        self.configuration.cisco_sb_connector,
-                        ipaddress=fabric_ip,
-                        username=fabric_user,
-                        password=fabric_pwd,
-                        port=fabric_port,
-                        vsan=zoning_vsan)
-                    if zone_map:
+                LOG.info(_("Zone map to add: %s"), zone_map)
+
+                if len(zone_map) > 0:
+                    conn = None
+                    try:
+                        conn = importutils.import_object(
+                            self.configuration.cisco_sb_connector,
+                            ipaddress=fabric_ip,
+                            username=fabric_user,
+                            password=fabric_pwd,
+                            port=fabric_port,
+                            vsan=zoning_vsan)
                         conn.add_zones(
-                            zone_map,
-                            self.configuration.cisco_zone_activate,
+                            zone_map, self.configuration.cisco_zone_activate,
                             zoning_vsan, cfgmap_from_fabric,
                             statusmap_from_fabric)
-                    if zone_update_map:
-                        conn.update_zones(
-                            zone_update_map,
-                            self.configuration.cisco_zone_activate,
-                            zoning_vsan, ZoneConstant.ZONE_ADD,
-                            cfgmap_from_fabric,
-                            statusmap_from_fabric)
-                    conn.cleanup()
-                except c_exception.CiscoZoningCliException as cisco_ex:
-                    msg = _("Exception: %s") % str(cisco_ex)
-                    raise exception.FCZoneDriverException(msg)
-                except Exception:
-                    msg = _("Failed to add zoning configuration.")
-                    LOG.exception(msg)
-                    raise exception.FCZoneDriverException(msg)
+                        conn.cleanup()
+                    except exception.CiscoZoningCliException as cisco_ex:
+                        msg = _("Exception: %s") % six.text_type(cisco_ex)
+                        raise exception.FCZoneDriverException(msg)
+                    except Exception as e:
+                        LOG.error(_("Exception: %s") % six.text_type(e))
+                        msg = (_("Failed to add zoning configuration %s") %
+                               six.text_type(e))
+                        raise exception.FCZoneDriverException(msg)
                 LOG.debug("Zones added successfully: %s", zone_map)
             else:
-                LOG.debug("Zones already exist - Initiator Target Map: %s",
-                          initiator_target_map)
-        else:
-            LOG.debug("Zoning session exists VSAN: %s", zoning_vsan)
+                LOG.debug("Zoning session exists VSAN: %s", zoning_vsan)
 
     @lockutils.synchronized('cisco', 'fcfabric-', True)
-    def delete_connection(self, fabric, initiator_target_map, host_name=None,
-                          storage_system=None):
+    def delete_connection(self, fabric, initiator_target_map):
         """Concrete implementation of delete_connection.
 
         Based on zoning policy and state of each I-T pair, list of zones
@@ -294,8 +236,8 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
         :param fabric: Fabric name from cinder.conf file
         :param initiator_target_map: Mapping of initiator to list of targets
         """
-        LOG.debug("Delete connection for fabric: %s", fabric)
-        LOG.info("CiscoFCZoneDriver - Delete connection for I-T map: %s",
+        LOG.debug("Delete connection for fabric:%s", fabric)
+        LOG.info(_("CiscoFCZoneDriver - Delete connection for I-T map: %s"),
                  initiator_target_map)
         fabric_ip = self.fabric_configs[fabric].safe_get(
             'cisco_fc_fabric_address')
@@ -308,18 +250,13 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
         zoning_policy = self.configuration.zoning_policy
         zoning_policy_fab = self.fabric_configs[fabric].safe_get(
             'cisco_zoning_policy')
-        zone_name_prefix = self.fabric_configs[fabric].safe_get(
-            'cisco_zone_name_prefix')
-
-        if not zone_name_prefix:
-            zone_name_prefix = self.configuration.cisco_zone_name_prefix
 
         if zoning_policy_fab:
             zoning_policy = zoning_policy_fab
 
         zoning_vsan = self.fabric_configs[fabric].safe_get('cisco_zoning_vsan')
 
-        LOG.info("Zoning policy for fabric %s", zoning_policy)
+        LOG.info(_("Zoning policy for fabric %s"), zoning_policy)
 
         statusmap_from_fabric = self.get_zoning_status(
             fabric_ip, fabric_user, fabric_pwd, fabric_port, zoning_vsan)
@@ -340,8 +277,8 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
             LOG.debug("zone config from Fabric: %s", cfgmap_from_fabric)
             for initiator_key in initiator_target_map.keys():
                 initiator = initiator_key.lower()
-                formatted_initiator = zm_utils.get_formatted_wwn(initiator)
-                zone_update_map = {}
+                formatted_initiator = get_formatted_wwn(initiator)
+                zone_map = {}
                 zones_to_delete = []
                 t_list = initiator_target_map[initiator_key]
                 if zoning_policy == 'initiator-target':
@@ -349,14 +286,9 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                     for t in t_list:
                         target = t.lower()
                         zone_name = (
-                            driver_utils.get_friendly_zone_name(
-                                zoning_policy,
-                                initiator,
-                                target,
-                                host_name,
-                                storage_system,
-                                zone_name_prefix,
-                                SUPPORTED_CHARS))
+                            self.configuration.cisco_zone_name_prefix
+                            + initiator.replace(':', '')
+                            + target.replace(':', ''))
                         LOG.debug("Zone name to del: %s", zone_name)
                         if (len(zone_names) > 0 and (zone_name in zone_names)):
                             # delete zone.
@@ -368,49 +300,36 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                     zone_members = [formatted_initiator]
                     for t in t_list:
                         target = t.lower()
-                        zone_members.append(
-                            zm_utils.get_formatted_wwn(target))
+                        zone_members.append(get_formatted_wwn(target))
+
+                    zone_name = self.configuration.cisco_zone_name_prefix \
+                        + initiator.replace(':', '')
 
-                    zone_name = driver_utils.get_friendly_zone_name(
-                        zoning_policy,
-                        initiator,
-                        target,
-                        host_name,
-                        storage_system,
-                        zone_name_prefix,
-                        SUPPORTED_CHARS)
-                    # Check if there are zone members leftover after removal
                     if (zone_names and (zone_name in zone_names)):
-                        filtered_members = list(filter(
+                        filtered_members = filter(
                             lambda x: x not in zone_members,
-                            cfgmap_from_fabric['zones'][zone_name]))
+                            cfgmap_from_fabric['zones'][zone_name])
 
                         # The assumption here is that initiator is always
                         # there in the zone as it is 'initiator' policy.
-                        # If filtered list is empty, we remove that zone.
-                        # If there are other members leftover, then perform
-                        # update_zone to remove targets
-                        LOG.debug("Zone delete - I mode: filtered targets: %s",
+                        # We find the filtered list and if it is non-empty,
+                        # add initiator to it and update zone if filtered
+                        # list is empty, we remove that zone.
+                        LOG.debug("Zone delete - I mode: filtered targets:%s",
                                   filtered_members)
                         if filtered_members:
-                            remove_members = list(filter(
-                                lambda x: x in
-                                cfgmap_from_fabric['zones'][zone_name],
-                                zone_members))
-                            if remove_members:
-                                # Do not want to remove the initiator
-                                remove_members.remove(formatted_initiator)
-                                LOG.debug("Zone members to remove: %s",
-                                          remove_members)
-                                zone_update_map[zone_name] = remove_members
-                                LOG.debug("Filtered zone Map to update: %s",
-                                          zone_update_map)
+                            filtered_members.append(formatted_initiator)
+                            LOG.debug("Filtered zone members to update: %s",
+                                      filtered_members)
+                            zone_map[zone_name] = filtered_members
+                            LOG.debug("Filtered zone Map to update: %s",
+                                      zone_map)
                         else:
                             zones_to_delete.append(zone_name)
                 else:
-                    LOG.info("Zoning Policy: %s, not recognized",
+                    LOG.info(_("Zoning Policy: %s, not recognized"),
                              zoning_policy)
-                LOG.debug("Zone map to remove update: %s", zone_update_map)
+                LOG.debug("Final Zone map to update: %s", zone_map)
                 LOG.debug("Final Zone list to delete: %s", zones_to_delete)
                 conn = None
                 try:
@@ -422,12 +341,11 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                         port=fabric_port,
                         vsan=zoning_vsan)
                     # Update zone membership.
-                    if zone_update_map:
-                        conn.update_zones(
-                            zone_update_map,
-                            self.configuration.cisco_zone_activate,
-                            zoning_vsan, ZoneConstant.ZONE_REMOVE,
-                            cfgmap_from_fabric, statusmap_from_fabric)
+                    if zone_map:
+                        conn.add_zones(
+                            zone_map, self.configuration.cisco_zone_activate,
+                            zoning_vsan, cfgmap_from_fabric,
+                            statusmap_from_fabric)
                     # Delete zones ~sk.
                     if zones_to_delete:
                         zone_name_string = ''
@@ -448,11 +366,12 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                                           zoning_vsan, cfgmap_from_fabric,
                                           statusmap_from_fabric)
                     conn.cleanup()
-                except Exception:
+                except Exception as e:
+                    msg = _("Exception: %s") % six.text_type(e)
+                    LOG.error(msg)
                     msg = _("Failed to update or delete zoning configuration")
-                    LOG.exception(msg)
                     raise exception.FCZoneDriverException(msg)
-                LOG.debug("Zones deleted successfully: %s", zone_update_map)
+                LOG.debug("Zones deleted successfully: %s", zone_map)
             else:
                 LOG.debug("Zoning session exists VSAN: %s", zoning_vsan)
 
@@ -470,8 +389,7 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
         LOG.debug("Target wwn List: %s", target_wwn_list)
         if len(fabrics) > 0:
             for t in target_wwn_list:
-                formatted_target_list.append(
-                    zm_utils.get_formatted_wwn(t.lower()))
+                formatted_target_list.append(get_formatted_wwn(t.lower()))
             LOG.debug("Formatted Target wwn List: %s", formatted_target_list)
             for fabric_name in fabrics:
                 fabric_ip = self.fabric_configs[fabric_name].safe_get(
@@ -496,30 +414,32 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                         password=fabric_pwd, port=fabric_port,
                         vsan=zoning_vsan)
                     nsinfo = conn.get_nameserver_info()
-                    LOG.debug("show fcns database info from fabric: %s",
-                              nsinfo)
+                    LOG.debug("show fcns database info from fabric:%s", nsinfo)
                     conn.cleanup()
-                except c_exception.CiscoZoningCliException:
+                except exception.CiscoZoningCliException as ex:
                     with excutils.save_and_reraise_exception():
-                        LOG.exception("Error getting show fcns database info.")
-                except Exception:
-                    msg = _("Failed to get show fcns database info.")
-                    LOG.exception(msg)
+                        LOG.error(_("Error getting show fcns database "
+                                    "info: %s"), six.text_type(ex))
+                except Exception as e:
+                    msg = (_("Failed to get show fcns database info:%s") %
+                           six.text_type(e))
+                    LOG.error(msg)
                     raise exception.FCZoneDriverException(msg)
-                visible_targets = list(filter(
-                    lambda x: x in formatted_target_list, nsinfo))
+                visible_targets = filter(
+                    lambda x: x in formatted_target_list, nsinfo)
 
                 if visible_targets:
-                    LOG.info("Filtered targets for SAN is: %s",
+                    LOG.info(_("Filtered targets for SAN is: %s"),
                              {fabric_name: visible_targets})
                     # getting rid of the ':' before returning
-                    fabric_map[fabric_name] = list(map(
-                        lambda x: re.sub(r':', '', x), visible_targets))
-
+                    for idx, elem in enumerate(visible_targets):
+                        visible_targets[idx] = six.text_type(
+                            visible_targets[idx]).replace(':', '')
+                    fabric_map[fabric_name] = visible_targets
                 else:
                     LOG.debug("No targets are in the fcns info for SAN %s",
                               fabric_name)
-        LOG.debug("Return SAN context output: %s", fabric_map)
+        LOG.debug("Return SAN context output:%s", fabric_map)
         return fabric_map
 
     def get_active_zone_set(self, fabric_ip,
@@ -537,9 +457,10 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                 password=fabric_pwd, port=fabric_port, vsan=zoning_vsan)
             cfgmap = conn.get_active_zone_set()
             conn.cleanup()
-        except Exception:
-            msg = _("Failed to access active zoning configuration.")
-            LOG.exception(msg)
+        except Exception as e:
+            msg = (_("Failed to access active zoning configuration:%s") %
+                   six.text_type(e))
+            LOG.error(msg)
             raise exception.FCZoneDriverException(msg)
         LOG.debug("Active zone set from fabric: %s", cfgmap)
         return cfgmap
@@ -558,9 +479,10 @@ class CiscoFCZoneDriver(fc_zone_driver.FCZoneDriver):
                 password=fabric_pwd, port=fabric_port, vsan=zoning_vsan)
             statusmap = conn.get_zoning_status()
             conn.cleanup()
-        except Exception:
-            msg = _("Failed to access zoneset status:%s")
-            LOG.exception(msg)
+        except Exception as e:
+            msg = (_("Failed to access zoneset status:%s") %
+                   six.text_type(e))
+            LOG.error(msg)
             raise exception.FCZoneDriverException(msg)
         LOG.debug("Zoneset status from fabric: %s", statusmap)
         return statusmap
