@@ -24,6 +24,7 @@ defined in this class.
 """
 
 from cinder import exception
+from cinder.i18n import _
 from cinder.openstack.common import importutils
 from cinder.openstack.common import log as logging
 from cinder.volume import configuration as config
@@ -74,8 +75,8 @@ class FCSanLookupService(fc_common.FCCommon):
         # Initialize vendor specific implementation of  FCZoneDriver
         if (self.configuration.fc_san_lookup_service):
             lookup_service = self.configuration.fc_san_lookup_service
-            LOG.debug(_("Lookup service to invoke: "
-                        "%s"), lookup_service)
+            LOG.debug("Lookup service to invoke: "
+                      "%s", lookup_service)
             self.lookup_service = importutils.import_object(
                 lookup_service, configuration=self.configuration)
         else:
